@@ -1,4 +1,4 @@
-#' Yeo-Johnson Transformation
+#' Yeo-Johnson transformation
 #'
 #' `step_YeoJohnson()` creates a *specification* of a recipe step that will
 #' transform data using a Yeo-Johnson transformation.
@@ -32,9 +32,14 @@
 #'
 #' # Tidying
 #'
-#' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
-#' `terms` (the selectors or variables selected) and `value` (the
-#' lambda estimate) is returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms`, `value` , and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{value}{numeric, the lambda estimate}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' @template case-weights-not-supported
 #'
@@ -104,6 +109,14 @@ step_YeoJohnson_new <-
 prep.step_YeoJohnson <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names], types = c("double", "integer"))
+  check_number_whole(x$num_unique, args = "num_unique")
+  check_bool(x$na_rm, arg = "na_rm")
+  if (!is.numeric(x$limits) || any(is.na(x$limits)) || length(x$limits) != 2) {
+    cli::cli_abort("{.arg limits} should be a numeric vector with two values,
+                    not {.obj_type_friendly {x$limits}}")
+  }
+
+  x$limits <- sort(x$limits)
 
   values <- vapply(
     training[, col_names],
@@ -142,6 +155,7 @@ bake.step_YeoJohnson <- function(object, new_data, ...) {
   new_data
 }
 
+#' @export
 print.step_YeoJohnson <-
   function(x, width = max(20, options()$width - 39), ...) {
     title <- "Yeo-Johnson transformation on "
@@ -152,10 +166,9 @@ print.step_YeoJohnson <-
 ## computes the new data given a lambda
 #' Internal Functions
 #'
-#' These are not to be used directly by the users.
-#' @export
 #' @keywords internal
 #' @rdname recipes-internal
+#' @export
 yj_transform <- function(x, lambda, ind_neg = NULL, eps = 0.001) {
   if (is.na(lambda)) {
     return(x)
@@ -220,9 +233,9 @@ yj_obj <- function(lam, dat, ind_neg, const) {
 }
 
 ## estimates the values
-#' @export
 #' @keywords internal
 #' @rdname recipes-internal
+#' @export
 estimate_yj <- function(dat,
                         limits = c(-5, 5),
                         num_unique = 5,
@@ -233,8 +246,11 @@ estimate_yj <- function(dat,
     if (na_rm) {
       dat <- dat[-na_rows]
     } else {
-      rlang::abort(
-        "Missing values are not allowed for the YJ transformation. See `na_rm` option",
+      cli::cli_abort(
+        c(
+          x = "Missing values are not allowed for the YJ transformation.",
+          i = "See {.arg na_rm} option."
+        ),
         call = call
       )
     }
