@@ -1,4 +1,4 @@
-#' Check Variable Class
+#' Check variable class
 #'
 #' `check_class` creates a *specification* of a recipe
 #'  check that will check if a variable is of a designated class.
@@ -102,6 +102,8 @@ check_class <-
 check_class_new <-
   function(terms, role, trained, class_nm,
            allow_additional, class_list, skip, id) {
+    check_character(class_nm, allow_null = TRUE, call = rlang::caller_env(2))
+    check_bool(allow_additional, call = rlang::caller_env(2))
     check(
       subclass         = "class",
       terms            = terms,
@@ -156,30 +158,20 @@ bake_check_class_core <- function(x,
   classes <- class(x)
   missing <- setdiff(class_nm, classes)
   if (length(missing) > 0) {
-    rlang::abort(
-      paste0(
-        var_nm,
-        " should have the class(es) ",
-        paste(class_nm, collapse = ", "),
-        " but has the class(es) ",
-        paste(classes, collapse = ", "),
-        "."
-      )
+    cli::cli_abort(
+      "{.var {var_nm}} should have the class{?es} {.cls {class_nm}} but
+      has the class{?es} {.and {.cls {classes}}}."
     )
   }
 
   extra <- setdiff(classes, class_nm)
   if (length(extra) > 0 && !aa) {
-    rlang::abort(
-      paste0(
-        var_nm,
-        " has the class(es) ",
-        paste(classes, collapse = ", "),
-        ", but only the following is/are asked ",
-        paste(class_nm, collapse = ", "),
-        ", allow_additional is FALSE."
-      )
-    )
+    cli::cli_abort(c(
+        x = "{.var {var_nm}} has class{?es} {.and {.cls {classes}}} but only \\
+            the following {?is/are} asked: {.and {.cls {class_nm}}}.",
+        i = "This error is shown because {.arg allow_additional} is set to \\
+            {.val FALSE}."
+    ))
   }
 }
 
@@ -199,6 +191,7 @@ bake.check_class <- function(object, new_data, ...) {
   new_data
 }
 
+#' @export
 print.check_class <-
   function(x, width = max(20, options()$width - 30), ...) {
     title <- "Checking the class(es) for "
