@@ -40,11 +40,20 @@
 #'
 #' # Tidying
 #'
-#' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
-#' `terms` (the selectors or variables selected), `value` (the centroid),
-#' `class`, and `type` is returned. Type has values `"global"`, `"by_class"`,
-#' and `"shrunken"`. The first two types of centroids are in the original units
-#' while the last have been standardized.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms`, `value`, `class`, `type`, `threshold` , and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{value}{numeric, the centroid}
+#'   \item{class}{character, name of class variable}
+#'   \item{type}{character, has values `"global"`, `"by_class"`, and `"shrunken"`}
+#'   \item{threshold}{numeric, value of threshold}
+#'   \item{id}{character, id of this step}
+#' }
+#'
+#' The first two types of centroids are in the original units while the last
+#' has been standardized.
 #'
 #' @template case-weights-supervised
 #' @references
@@ -53,7 +62,7 @@
 #' of the National Academy of Sciences_, 99(10), 6567-6572.
 #' @examplesIf rlang::is_installed(c("modeldata"))
 #' data(penguins, package = "modeldata")
-#' penguins <- penguins[complete.cases(penguins), ]
+#' penguins <- penguins[vctrs::vec_detect_complete(penguins), ]
 #' penguins$island <- NULL
 #' penguins$sex <- NULL
 #'
@@ -73,7 +82,7 @@
 #'
 #' rec_dists <- prep(rec, training = penguins)
 #'
-#' dists_to_species <- bake(rec_dists, new_data = penguins, everything())
+#' dists_to_species <- bake(rec_dists, new_data = penguins)
 #' ## on log scale:
 #' dist_cols <- grep("classdist", names(dists_to_species), value = TRUE)
 #' dists_to_species[, c("species", dist_cols)]
@@ -276,12 +285,12 @@ prep.step_classdist_shrunken <- function(x, training, info = NULL, ...) {
   check_type(training[, y_names], types = c("factor"))
 
   threshold <- x$threshold
-  stopifnot(all(threshold >= 0) & all(threshold <= 1) &
-              length(threshold) == 1 & all(!is.na(threshold)))
+  check_number_decimal(threshold, min = 0, max = 1)
 
   sd_offset <- x$sd_offset
-  stopifnot(all(sd_offset >= 0) & all(sd_offset <= 1) &
-              length(sd_offset) == 1 & all(!is.na(sd_offset)))
+  check_number_decimal(sd_offset, min = 0, max = 1)
+  check_bool(x$log)
+  check_string(x$prefix)
 
   wts <- get_case_weights(info, training)
   were_weights_used <- are_weights_used(wts)
@@ -346,6 +355,7 @@ bake.step_classdist_shrunken <- function(object, new_data, ...) {
   new_data
 }
 
+#' @export
 print.step_classdist_shrunken <-
   function(x, width = max(20, options()$width - 30), ...) {
     preds <- unique(x$objects$variable)
