@@ -1,4 +1,4 @@
-#' Check if all Columns are Present
+#' Check if all columns are present
 #'
 #' `check_cols` creates a *specification* of a recipe
 #'  step that will check if all the columns of the training frame are
@@ -81,18 +81,19 @@ bake.check_cols <- function(object, new_data, ...) {
   new_cols <- names(new_data)
   missing <- setdiff(original_cols, new_cols)
   if (length(missing) > 0) {
-    mis_cols <- paste(paste0("`", missing, "`"), collapse = ", ")
-    rlang::abort(
-      paste0(
-        "The following cols are missing from `new_data`: ",
-        mis_cols,
-        "."
-      )
-    )
+    # This is functionally not reachable after we added ptype checking in
+    # https://github.com/tidymodels/recipes/pull/1330
+    # but it feels too harsh to deprecate this check function.
+    cli::cli_abort(c(
+      x = "{cli::qty(length(missing))}The following column{?s} {?is/are} \\
+      missing from {.arg new_data}:",
+      "*" = "{.and {.var {missing}}}."
+    ))
   }
   new_data
 }
 
+#' @export
 print.check_cols <-
   function(x, width = max(20, options()$width - 30), ...) {
     title <- "Check if the following columns are present: "
