@@ -1,4 +1,4 @@
-#' High Correlation Filter
+#' High correlation filter
 #'
 #' `step_corr()` creates a *specification* of a recipe step that will
 #' potentially remove variables that have large absolute correlations with other
@@ -39,8 +39,13 @@
 #'
 #' # Tidying
 #'
-#' When you [`tidy()`][tidy.recipe()] this step, a tibble with column
-#' `terms` (the columns that will be removed) is returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms` and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected to be removed}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' ```{r, echo = FALSE, results="asis"}
 #' step <- "step_corr"
@@ -124,6 +129,12 @@ step_corr_new <-
 prep.step_corr <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names], types = c("double", "integer"))
+  check_number_decimal(x$threshold, min = 0, max = 1, arg = "threshold")
+  use <- x$use
+  rlang::arg_match(use, c("all.obs", "complete.obs", "pairwise.complete.obs",
+                            "everything", "na.or.complete"))
+  method <- x$method
+  rlang::arg_match(method, c("pearson", "kendall", "spearman"))
 
   wts <- get_case_weights(info, training)
   were_weights_used <- are_weights_used(wts, unsupervised = TRUE)
@@ -163,6 +174,7 @@ bake.step_corr <- function(object, new_data, ...) {
   new_data
 }
 
+#' @export
 print.step_corr <-
   function(x, width = max(20, options()$width - 36), ...) {
     title <- "Correlation filter on "
@@ -179,31 +191,28 @@ corr_filter <-
            method = "pearson") {
     x <- correlations(x, wts = wts, use = use, method = method)
 
-    if (any(!complete.cases(x))) {
+    if (any(!vec_detect_complete(x))) {
       all_na <- apply(x, 2, function(x) all(is.na(x)))
       if (sum(all_na) >= nrow(x) - 1) {
-        rlang::warn("Too many correlations are `NA`; skipping correlation filter.")
+        cli::cli_warn(
+          "Too many correlations are `NA`; skipping correlation filter."
+        )
         return(numeric(0))
       } else {
         na_cols <- which(all_na)
         if (length(na_cols) > 0) {
           x[na_cols, ] <- 0
           x[, na_cols] <- 0
-          rlang::warn(
-            paste0(
-              "The correlation matrix has missing values. ",
-              length(na_cols),
-              " columns were excluded from the filter."
-            )
+          cli::cli_warn(
+            "The correlation matrix has missing values. \\
+            {length(na_cols)} column{?s} {?was/were} excluded from the filter."
           )
         }
       }
       if (any(is.na(x))) {
-        rlang::warn(
-          paste0(
-            "The correlation matrix has sporadic missing values. ",
-            "Some columns were excluded from the filter."
-          )
+        cli::cli_warn(
+          "The correlation matrix has sporadic missing values. \\
+          Some columns were excluded from the filter."
         )
         x[is.na(x)] <- 0
       }
