@@ -19,6 +19,17 @@
 #'  `step_cut()` will call `base::cut()` in the baking step with
 #'  `include.lowest` set to `TRUE`.
 #'
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms`, `value` , and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{value}{numeric, the location of the cuts}
+#'   \item{id}{character, id of this step}
+#' }
+#'
 #' @template case-weights-not-supported
 #'
 #' @examples
@@ -102,6 +113,13 @@ prep.step_cut <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names], types = c("double", "integer"))
 
+  if (!is.numeric(x$breaks)) {
+    cli::cli_abort(
+      "{.arg breaks} must be a numeric vector, not {.obj_type_friendly {x$breaks}}."
+    )
+  }
+  check_bool(x$include_outside_range, arg = "include_outside_range")
+
   all_breaks <- vector("list", length(col_names))
   names(all_breaks) <- col_names
   for (col_name in col_names) {
@@ -121,23 +139,50 @@ prep.step_cut <- function(x, training, info = NULL, ...) {
   )
 }
 
-create_full_breaks <- function(var, breaks) {
-  stopifnot(is.numeric(var), is.numeric(breaks))
+create_full_breaks <- function(var, breaks, call = rlang::caller_env()) {
+  if (!is.numeric(var)) {
+    cli::cli_abort(
+      "{.arg var} must be a numeric vector, not {.obj_type_friendly {var}}.",
+      call = call
+    )
+  }
+
+  if (!is.numeric(breaks)) {
+    cli::cli_abort(
+      "{.arg breaks} must be a numeric vector, not {.obj_type_friendly {breaks}}.",
+      call = call
+    )
+  }
+
+  if (any(is.na(var))) {
+    cli::cli_warn(
+      "{.arg var} contains missing values. These will be ignored in break
+       calculations.",
+      call = call
+    )
+    var <- var[!is.na(var)]
+  }
+
   if (min(var) < min(breaks)) {
     breaks <- c(min(var), breaks)
   }
+
   if (max(var) > max(breaks)) {
     breaks <- c(max(var), breaks)
   }
+
   sort(breaks)
 }
 
-full_breaks_check <- function(breaks) {
+full_breaks_check <- function(breaks, call = rlang::caller_env()) {
   if (length(breaks) == 1) {
-    rlang::abort("In step_cut: variable is invariant and equal to break point.")
+    cli::cli_abort(
+      "Variable is invariant and equal to break point.",
+      call = call
+    )
   }
   if (length(breaks) == 2) {
-    rlang::warn("In step_cut: this will create a factor with one value only.")
+    cli::cli_warn("This will create a factor with one value only.")
   }
 }
 
@@ -178,7 +223,6 @@ cut_var <- function(var, breaks, include_outside_range) {
 # the levels when bake.recipe itself is called. Moreover,
 # it is cleaner to show it in this way.
 adjust_levels_min_max <- function(x) {
-  stopifnot(is.factor(x))
   levs <- levels(x)
   if (length(levs) == 1) {
     return(factor(rep("[min,max]", length(x))))
@@ -195,6 +239,7 @@ adjust_levels_min_max <- function(x) {
   factor(new_x, levels = new_levs)
 }
 
+#' @export
 print.step_cut <-
   function(x, width = max(20, options()$width - 30), ...) {
     title <- "Cut numeric for "
@@ -206,17 +251,14 @@ print.step_cut <-
 #' @export
 tidy.step_cut <- function(x, ...) {
   if (is_trained(x)) {
-    values <- vapply(
-      unname(x$class_list),
-      FUN = function(x) paste0(x, collapse = "-"),
-      FUN.VALUE = character(1)
+    res <- tibble(
+      terms = rep(names(x$breaks), lengths(x$breaks)),
+      value = unlist(x$breaks, use.names = FALSE) %||% double()
     )
-
-    res <- tibble(terms = names(x$breaks), value = values)
   } else {
     term_names <- sel2char(x$terms)
-    res <- tibble(terms = term_names, value = na_chr)
+    res <- tibble(terms = term_names, value = na_dbl)
   }
-  res$id <- x$id
+  res$id <- rep(x$id, nrow(res))
   res
 }
