@@ -1,9 +1,10 @@
-#' Data Depths
+#' Data depths
 #'
 #' `step_depth()` creates a *specification* of a recipe step that will convert
 #' numeric data into a measurement of *data depth*. This is done for each value of
 #' a categorical class variable.
 #'
+#' @inheritParams step_classdist
 #' @inheritParams step_pca
 #' @inheritParams step_center
 #' @param class A single character string that specifies a single
@@ -51,10 +52,16 @@
 #'  replace the original values and by default have the prefix `depth_`. The
 #'  naming format can be changed using the `prefix` argument.
 #'
-#'  # Tidying
+#' # Tidying
 #'
-#'  When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
-#'  `terms` (the selectors or variables selected) and `class` is returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms`, `class` , and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{class}{character, name of class variable}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' @template case-weights-not-supported
 #'
@@ -92,10 +99,8 @@ step_depth <-
            keep_original_cols = TRUE,
            skip = FALSE,
            id = rand_id("depth")) {
-    if (!is.character(class) || length(class) != 1) {
-      rlang::abort("`class` should be a single character value.")
-    }
 
+    check_string(class)
     recipes_pkg_check(required_pkgs.step_depth())
 
     add_step(
@@ -135,10 +140,16 @@ step_depth_new <-
     )
   }
 
+depth_metric <- c("potential", "halfspace", "Mahalanobis", "simplicialVolume",
+                  "spatial", "zonoid")
+
 #' @export
 prep.step_depth <- function(x, training, info = NULL, ...) {
   x_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, x_names], types = c("double", "integer"))
+  metric <- x$metric
+  rlang::arg_match(metric, depth_metric)
+  check_string(x$prefix, allow_empty = FALSE, arg = "prefix")
 
   class_var <- x$class[1]
 
@@ -204,6 +215,7 @@ bake.step_depth <- function(object, new_data, ...) {
   new_data
 }
 
+#' @export
 print.step_depth <-
   function(x, width = max(20, options()$width - 30), ...) {
     title <- glue("Data depth by {x$class} for ")
