@@ -13,7 +13,10 @@ discretize <- function(x, ...) {
 #' @export
 #' @rdname discretize
 discretize.default <- function(x, ...) {
-  rlang::abort("Only numeric `x` is accepted")
+  cli::cli_abort(c(
+    x = "Only numeric {.arg x} is accepted.",
+    i = "The {.arg x} was passed {.obj_type_friendly {x}}."
+  ))
 }
 
 #' @rdname discretize
@@ -87,10 +90,7 @@ discretize.numeric <-
            ...) {
     unique_vals <- length(unique(x))
     missing_lab <- "_missing"
-
-    if (cuts < 2) {
-      rlang::abort("There should be at least 2 cuts")
-    }
+    check_number_whole(cuts, min = 2)
 
     dots <- list(...)
     if (keep_na) {
@@ -109,14 +109,9 @@ discretize.numeric <-
       num_breaks <- length(breaks)
       breaks <- unique(breaks)
       if (num_breaks > length(breaks)) {
-        rlang::warn(
-          paste0(
-            "Not enough data for ",
-            cuts,
-            " breaks. Only ",
-            length(breaks),
-            " breaks were used."
-          )
+        cli::cli_warn(
+          "Not enough data for {cuts} breaks. Only {length(breaks)} breaks
+           were used."
         )
       }
       if (infs) {
@@ -128,13 +123,10 @@ discretize.numeric <-
       if (is.null(labels)) {
         prefix <- prefix[1]
         if (make.names(prefix) != prefix && !is.null(prefix)) {
-          rlang::warn(paste0(
-            "The prefix '",
-            prefix,
-            "' is not a valid R name. It has been changed to '",
-            make.names(prefix),
-            "'."
-          ))
+          cli::cli_warn(
+            "The prefix {.val {prefix}} is not a valid R name. It has been
+            changed to {.val {make.names(prefix)}}."
+          )
           prefix <- make.names(prefix)
         }
         labels <- names0(length(breaks) - 1, "")
@@ -152,11 +144,9 @@ discretize.numeric <-
       )
     } else {
       out <- list(bins = 0)
-      rlang::warn(
-        paste0(
-          "Data not binned; too few unique values per bin. ",
-          "Adjust 'min_unique' as needed"
-        )
+      cli::cli_warn(
+        "Data not binned; too few unique values per bin. Adjust
+         {.arg min_unique} as needed."
       )
     }
     class(out) <- "discretize"
@@ -259,9 +249,14 @@ print.discretize <-
 #'
 #' # Tidying
 #'
-#' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
-#' `terms` (the selectors or variables selected) and `value`
-#' (the breaks) is returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms`, `value` , and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{value}{numeric, the breaks}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' ```{r, echo = FALSE, results="asis"}
 #' step <- "step_discretize"
@@ -301,8 +296,10 @@ step_discretize <- function(recipe,
                             options = list(prefix = "bin"),
                             skip = FALSE,
                             id = rand_id("discretize")) {
-  if (any(names(options) %in% c("cuts", "min_unique"))) {
+  if (any(names(options) == "cuts")) {
     num_breaks <- options$cuts
+  }
+  if (any(names(options) == "min_unique")) {
     min_unique <- options$min_unique
   }
 
@@ -348,13 +345,13 @@ bin_wrapper <- function(x, args) {
 prep.step_discretize <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names], types = c("double", "integer"))
+  check_number_whole(x$num_breaks, min = 1, arg = "num_breaks")
+  check_number_whole(x$min_unique, min = 1, arg = "min_unique")
 
   if (length(col_names) > 1 & any(names(x$options) %in% c("prefix", "labels"))) {
-    rlang::warn(
-      paste0(
-        "Note that the options `prefix` and `labels` ",
-        "will be applied to all variables"
-      )
+    cli::cli_warn(
+      "Note that the options {.arg prefix} and {.arg labels} will be applied \\
+      to all variables."
     )
   }
 
@@ -390,6 +387,7 @@ bake.step_discretize <- function(object, new_data, ...) {
   new_data
 }
 
+#' @export
 print.step_discretize <-
   function(x, width = max(20, options()$width - 30), ...) {
     title <- "Discretize numeric variables from "
