@@ -7,10 +7,10 @@
 #' @inheritParams step_center
 #' @inheritParams step_other
 #' @inheritParams step_dummy
-#' @param sep Character vector containing a regular expression to use
+#' @param sep Character string containing a regular expression to use
 #'   for splitting. [strsplit()] is used to perform the split. `sep` takes
 #'   priority if `pattern` is also specified.
-#' @param pattern Character vector containing a regular expression used
+#' @param pattern Character string containing a regular expression used
 #'   for extraction. [gregexpr()] and [regmatches()] are used to perform
 #'   pattern extraction using `perl = TRUE`.
 #' @template step-return
@@ -18,7 +18,7 @@
 #' @seealso [dummy_extract_names()]
 #' @export
 #' @details `step_dummy_extract()` will create a set of integer dummy
-#'  variables from a character variable by extract individual strings
+#'  variables from a character variable by extracting individual strings
 #'  by either splitting or extracting then counting those to create
 #'  count variables.
 #'
@@ -31,12 +31,18 @@
 #'
 #' @details
 #'
-#'  # Tidying
+#' # Tidying
 #'
-#'  When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
-#'  `terms` (the selectors or original variables selected) and `columns`
-#'  (the list of corresponding columns) is returned. The `columns` is
-#'  is ordered according the frequency in the training data set.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms`, `columns` , and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{columns}{character, names of resulting columns}
+#'   \item{id}{character, id of this step}
+#' }
+#'
+#' The return value is ordered according to the frequency of `columns` entries in the training data set.
 #'
 #' @template case-weights-unsupervised
 #'
@@ -82,10 +88,10 @@
 #'   step_dummy_extract(colors, pattern = "(?<=')[^',]+(?=')") %>%
 #'   prep()
 #'
-#' dommies_data_color <- dummies_color %>%
+#' dummies_data_color <- dummies_color %>%
 #'   bake(new_data = NULL)
 #'
-#' dommies_data_color
+#' dummies_data_color
 step_dummy_extract <-
   function(recipe,
            ...,
@@ -100,14 +106,6 @@ step_dummy_extract <-
            keep_original_cols = FALSE,
            skip = FALSE,
            id = rand_id("dummy_extract")) {
-    if (!is_tune(threshold)) {
-      if (threshold < 0) {
-        rlang::abort("`threshold` should not be negative.")
-      }
-      if (threshold >= 1 && !is_integerish(threshold)) {
-        rlang::abort("If `threshold` is greater than one it should be an integer.")
-      }
-    }
 
     add_step(
       recipe,
@@ -154,6 +152,15 @@ step_dummy_extract_new <-
 prep.step_dummy_extract <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names], types = c("string", "factor", "ordered"))
+  if (x$threshold >= 1) {
+    check_number_whole(x$threshold, arg = "threshold")
+  } else {
+    check_number_decimal(x$threshold, min = 0, arg = "threshold")
+  }
+  check_string(x$other, arg = "other", allow_null = TRUE)
+  check_string(x$sep, arg = "sep", allow_null = TRUE)
+  check_string(x$pattern, arg = "pattern", allow_null = TRUE)
+  check_function(x$naming, arg = "naming", allow_empty = FALSE)
 
   wts <- get_case_weights(info, training)
   were_weights_used <- are_weights_used(wts, unsupervised = TRUE)
@@ -162,8 +169,6 @@ prep.step_dummy_extract <- function(x, training, info = NULL, ...) {
   }
 
   if (length(col_names) > 0) {
-    col_names <- check_factor_vars(training, col_names, "step_dummy_extract")
-
     levels <- vector(mode = "list", length = length(col_names))
     names(levels) <- col_names
     for (col_name in col_names) {
@@ -242,7 +247,8 @@ bake.step_dummy_extract <- function(object, new_data, ...) {
       sort(object$levels[[col_name]]),
       object$other
     )
-    indicators <- purrr::map_dfc(indicators, vec_cast, integer())
+    indicators <- purrr::map(indicators, vec_cast, integer())
+    indicators <- vctrs::vec_cbind(!!!indicators)
 
     ## use backticks for nonstandard factor levels here
     used_lvl <- gsub(paste0("^", col_name), "", colnames(indicators))
@@ -267,7 +273,7 @@ dummy_extract <- function(x, sep = NULL, pattern = NULL, call = caller_env()) {
     matches <- gregexpr(pattern = pattern, text = x, perl = TRUE)
     return(regmatches(x, m = matches))
   }
-  rlang::abort("`sep` or `pattern` must be specified.", call = call)
+  cli::cli_abort("{.arg sep} or {.arg pattern} must be specified.", call = call)
 }
 
 list_to_dummies <- function(x, dict, other = "other") {
@@ -288,6 +294,7 @@ list_to_dummies <- function(x, dict, other = "other") {
   tibble::as_tibble(out)
 }
 
+#' @export
 print.step_dummy_extract <-
   function(x, width = max(20, options()$width - 20), ...) {
     title <- "Extract patterns from "
@@ -301,7 +308,8 @@ print.step_dummy_extract <-
 tidy.step_dummy_extract <- function(x, ...) {
   if (is_trained(x)) {
     if (length(x$levels) > 0) {
-      res <- purrr::map_dfr(x$levels, ~ list(columns = .x), FALSE, .id = "terms")
+      res <- purrr::map(x$levels, ~ tibble(columns = .x), FALSE)
+      res <- purrr::list_rbind(res, names_to = "terms")
     } else {
       res <- tibble(terms = character(), columns = character())
     }
