@@ -12,12 +12,18 @@
 #'  This is `NULL` until the step is trained by [prep()].
 #' @template step-return
 #' @family dummy variable and encoding steps
-#' @export
+#'
 #' @details
-#'  The overall proportion (or total counts) of the categories are
-#'  computed. The "other" category is used in place of any categorical levels
-#'  whose individual proportion (or frequency) in the training set is less than
-#'  `threshold`.
+#' The overall proportion (or total counts) of the categories are computed. The
+#' `"other"` category is used in place of any categorical levels whose
+#' individual proportion (or frequency) in the training set is less than
+#' `threshold`.
+#'
+#' This step produces a number of columns, based on the number of categories it
+#' finds. The naming of the columns is determined by the function based on the
+#' `naming` argument. The default is to return `<prefix>_<category name>`. By
+#' default `prefix` is `NULL`, which means the name of the first column
+#' selected will be used in place.
 #'
 #' @template dummy-naming
 #'
@@ -68,6 +74,8 @@
 #'
 #' bake(dummy_multi_choice_rec2, new_data = NULL)
 #' tidy(dummy_multi_choice_rec2, number = 1)
+#'
+#' @export
 step_dummy_multi_choice <- function(recipe,
                                     ...,
                                     role = "predictor",
@@ -82,14 +90,6 @@ step_dummy_multi_choice <- function(recipe,
                                     skip = FALSE,
                                     id = rand_id("dummy_multi_choice")) {
 
-  if (!is_tune(threshold)) {
-    if (threshold >= 1) {
-      check_number_whole(threshold)
-    } else {
-      check_number_decimal(threshold, min = 0)
-    }
-  }
-
   add_step(
     recipe,
     step_dummy_multi_choice_new(
@@ -133,8 +133,13 @@ step_dummy_multi_choice_new <-
 prep.step_dummy_multi_choice <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names], types = c("nominal", "logical"))
-
-  multi_dummy_check_type(training[, col_names])
+  if (x$threshold >= 1) {
+    check_number_whole(x$threshold, arg = "threshold")
+  } else {
+    check_number_decimal(x$threshold, min = 0, arg = "threshold")
+  }
+  check_string(x$other, arg = "other", allow_null = TRUE)
+  check_function(x$naming, arg = "naming", allow_empty = FALSE)
 
   levels <- purrr::map(training[, col_names], levels)
   levels <- vctrs::list_unchop(levels, ptype = character(), name_spec = rlang::zap())
@@ -157,23 +162,6 @@ prep.step_dummy_multi_choice <- function(x, training, info = NULL, ...) {
   )
 }
 
-multi_dummy_check_type <- function(dat, call = rlang::caller_env()) {
-  is_good <- function(x) {
-    is.factor(x) | is.character(x) | all(is.na(x))
-  }
-
-  all_good <- vapply(dat, is_good, logical(1))
-  if (!all(all_good)) {
-    offenders <- names(dat)[!all_good]
-    cli::cli_abort(c(
-      "x" = "All columns selected for the step should be \\
-            factor, character, or NA. The following were not:",
-      "*" = "{.var {offenders}}."
-    ), call = call)
-  }
-  invisible(all_good)
-}
-
 #' @export
 bake.step_dummy_multi_choice <- function(object, new_data, ...) {
   col_names <- object$input
@@ -241,6 +229,7 @@ multi_dummy <- function(x, y) {
   return(res)
 }
 
+#' @export
 print.step_dummy_multi_choice <-
   function(x, width = max(20, options()$width - 20), ...) {
     title <- "Multi-choice dummy variables from "
