@@ -1,4 +1,4 @@
-#' Hyperbolic Transformations
+#' Hyperbolic transformations
 #'
 #' `step_hyperbolic()` creates a *specification* of a recipe step that will
 #' transform data using a hyperbolic function.
@@ -15,9 +15,15 @@
 #'
 #' # Tidying
 #'
-#' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
-#' `terms` (the columns that will be affected), `inverse`, and `func` is
-#' returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms`, `inverse`, `func` , and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{inverse}{logical, is the inverse function be used}
+#'   \item{func}{character, name of function. `"sinh"`, `"cosh"`, or `"tanh"`}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' @template case-weights-not-supported
 #'
@@ -52,8 +58,9 @@ step_hyperbolic <-
            skip = FALSE,
            id = rand_id("hyperbolic")) {
 
-    func <- rlang::arg_match(func)
-
+    if (!is_tune(func)) {
+      func <- rlang::arg_match(func)
+    }
     add_step(
       recipe,
       step_hyperbolic_new(
@@ -88,6 +95,9 @@ step_hyperbolic_new <-
 prep.step_hyperbolic <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names], types = c("double", "integer"))
+  func <- x$func
+  x$func <- rlang::arg_match(func, c("sinh", "cosh", "tanh"), error_arg = "func")
+  check_bool(x$inverse, error_arg = "inverse")
 
   step_hyperbolic_new(
     terms = x$terms,
@@ -119,6 +129,7 @@ bake.step_hyperbolic <- function(object, new_data, ...) {
   new_data
 }
 
+#' @export
 print.step_hyperbolic <-
   function(x, width = max(20, options()$width - 32), ...) {
     ttl <- paste("Hyperbolic", substr(x$func, 1, 3))
