@@ -34,9 +34,15 @@
 #'
 #' # Tidying
 #'
-#' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
-#' `terms` (the selectors or variables for imputation), `predictors`
-#' (those variables used to impute), and `neighbors` is returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms`, `predictors`, `neighbors` , and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{predictors}{character, selected predictors used to impute}
+#'   \item{neighbors}{integer, number of neighbors}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' ```{r, echo = FALSE, results="asis"}
 #' step <- "step_impute_knn"
@@ -102,16 +108,18 @@ step_impute_knn <-
            skip = FALSE,
            id = rand_id("impute_knn")) {
     if (is.null(impute_with)) {
-      rlang::abort("Please list some variables in `impute_with`")
+      cli::cli_abort("{.arg impute_with} must not be empty.")
     }
 
     if (!is.list(options)) {
-      rlang::abort("`options` should be a named list.")
+      cli::cli_abort("{.arg options} should be a named list.")
     }
     opt_nms <- names(options)
     if (length(options) > 0) {
       if (any(!(opt_nms %in% c("eps", "nthread")))) {
-        rlang::abort("Availible options are 'eps', and 'nthread'.")
+        cli::cli_abort(
+          "Valid values for {.arg options} are {.val eps} and {.val nthread}."
+        )
       }
       if (all(opt_nms != "nthread")) {
         options$nthread <- 1
@@ -140,40 +148,6 @@ step_impute_knn <-
     )
   }
 
-#' @rdname step_impute_knn
-#' @export
-step_knnimpute <-
-  function(recipe,
-           ...,
-           role = NA,
-           trained = FALSE,
-           neighbors = 5,
-           impute_with = imp_vars(all_predictors()),
-           options = list(nthread = 1, eps = 1e-08),
-           ref_data = NULL,
-           columns = NULL,
-           skip = FALSE,
-           id = rand_id("impute_knn")) {
-    lifecycle::deprecate_stop(
-      when = "0.1.16",
-      what = "recipes::step_knnimpute()",
-      with = "recipes::step_impute_knn()"
-    )
-    step_impute_knn(
-      recipe,
-      ...,
-      role = role,
-      trained = trained,
-      neighbors = neighbors,
-      impute_with = impute_with,
-      options = options,
-      ref_data = ref_data,
-      columns = columns,
-      skip = skip,
-      id = id
-    )
-  }
-
 step_impute_knn_new <-
   function(terms, role, trained, neighbors, impute_with, ref_data, options,
            columns, skip, id) {
@@ -194,6 +168,7 @@ step_impute_knn_new <-
 
 #' @export
 prep.step_impute_knn <- function(x, training, info = NULL, ...) {
+  check_number_whole(x$neighbors, arg = "neighbors", min = 1)
   var_lists <-
     impute_var_lists(
       to_impute = x$terms,
@@ -218,10 +193,6 @@ prep.step_impute_knn <- function(x, training, info = NULL, ...) {
   )
 }
 
-#' @export
-#' @keywords internal
-prep.step_knnimpute <- prep.step_impute_knn
-
 nn_index <- function(miss_data, ref_data, vars, K, opt) {
   gower_topn(
     ref_data[, vars],
@@ -251,7 +222,7 @@ bake.step_impute_knn <- function(object, new_data, ...) {
   all_cols <- unique(unlist(object$columns, recursive = TRUE))
   check_new_data(all_cols, object, new_data)
 
-  missing_rows <- !complete.cases(new_data)
+  missing_rows <- !vec_detect_complete(new_data)
   if (!any(missing_rows)) {
     return(new_data)
   }
@@ -260,7 +231,7 @@ bake.step_impute_knn <- function(object, new_data, ...) {
 
   old_data <- new_data
   for (col_name in col_names) {
-    missing_rows <- !complete.cases(new_data[, col_name])
+    missing_rows <- !vec_detect_complete(new_data[, col_name])
     if (!any(missing_rows)) {
       next
     }
@@ -268,7 +239,7 @@ bake.step_impute_knn <- function(object, new_data, ...) {
     imp_data <- old_data[missing_rows, preds, drop = FALSE]
     ## do a better job of checking this:
     if (all(is.na(imp_data))) {
-      rlang::warn("All predictors are missing; cannot impute")
+      cli::cli_warn("All predictors are missing; cannot impute.")
     } else {
       imp_var_complete <- !is.na(object$ref_data[[col_name]])
       nn_ind <- nn_index(
@@ -288,10 +259,6 @@ bake.step_impute_knn <- function(object, new_data, ...) {
   new_data
 }
 
-#' @export
-#' @keywords internal
-bake.step_knnimpute <- bake.step_impute_knn
-
 #' @export
 print.step_impute_knn <-
   function(x, width = max(20, options()$width - 31), ...) {
@@ -302,10 +269,6 @@ print.step_impute_knn <-
     invisible(x)
   }
 
-#' @export
-#' @keywords internal
-print.step_knnimpute <- print.step_impute_knn
-
 #' @rdname tidy.recipe
 #' @export
 tidy.step_impute_knn <- function(x, ...) {
@@ -327,10 +290,6 @@ tidy.step_impute_knn <- function(x, ...) {
   res
 }
 
-#' @export
-#' @keywords internal
-tidy.step_knnimpute <- tidy.step_impute_knn
-
 #' @export
 tunable.step_impute_knn <- function(x, ...) {
   tibble::tibble(
@@ -341,7 +300,3 @@ tunable.step_impute_knn <- function(x, ...) {
     component_id = x$id
   )
 }
-
-#' @export
-#' @keywords internal
-tunable.step_knnimpute <- tunable.step_impute_knn
