@@ -60,7 +60,7 @@
 #'
 #' imp_models <- prep(impute_rec, training = credit_tr)
 #'
-#' imputed_te <- bake(imp_models, new_data = credit_te, everything())
+#' imputed_te <- bake(imp_models, new_data = credit_te)
 #'
 #' credit_te[missing_examples, ]
 #' imputed_te[missing_examples, names(credit_te)]
@@ -91,34 +91,6 @@ step_impute_mean <-
     )
   }
 
-#' @rdname step_impute_mean
-#' @export
-step_meanimpute <-
-  function(recipe,
-           ...,
-           role = NA,
-           trained = FALSE,
-           means = NULL,
-           trim = 0,
-           skip = FALSE,
-           id = rand_id("impute_mean")) {
-    lifecycle::deprecate_stop(
-      when = "0.1.16",
-      what = "recipes::step_meanimpute()",
-      with = "recipes::step_impute_mean()"
-    )
-    step_impute_mean(
-      recipe,
-      ...,
-      role = role,
-      trained = trained,
-      means = means,
-      trim = trim,
-      skip = skip,
-      id = id
-    )
-  }
-
 step_impute_mean_new <-
   function(terms, role, trained, means, trim, skip, id, case_weights) {
     step(
@@ -141,14 +113,8 @@ trim <- function(x, trim) {
   # Adapted from mean.default
   x <- sort(x, na.last = TRUE)
   na_ind <- is.na(x)
-  if (!is.numeric(trim) || length(trim) != 1L) {
-    cli::cli_abort("{.arg trim} must be numeric of length one.")
-  }
   n <- length(x[!na_ind])
   if (trim > 0 && n) {
-    if (is.complex(x)) {
-      cli::cli_abort("Trimmed means are not defined for complex data.")
-    }
     if (trim >= 0.5)
       return(stats::median(x[!na_ind], na.rm = FALSE))
     lo <- floor(n * trim) + 1
@@ -163,6 +129,7 @@ trim <- function(x, trim) {
 prep.step_impute_mean <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names], types = c("double", "integer"))
+  check_number_decimal(x$trim, arg = "trim", min = 0, max = 1/2)
 
   wts <- get_case_weights(info, training)
   were_weights_used <- are_weights_used(wts, unsupervised = TRUE)
@@ -188,10 +155,6 @@ prep.step_impute_mean <- function(x, training, info = NULL, ...) {
   )
 }
 
-#' @export
-#' @keywords internal
-prep.step_meanimpute <- prep.step_impute_mean
-
 #' @export
 bake.step_impute_mean <- function(object, new_data, ...) {
   col_names <- names(object$means)
@@ -208,10 +171,6 @@ bake.step_impute_mean <- function(object, new_data, ...) {
   new_data
 }
 
-#' @export
-#' @keywords internal
-bake.step_meanimpute <- bake.step_impute_mean
-
 #' @export
 print.step_impute_mean <-
   function(x, width = max(20, options()$width - 30), ...) {
@@ -221,10 +180,6 @@ print.step_impute_mean <-
     invisible(x)
   }
 
-#' @export
-#' @keywords internal
-print.step_meanimpute <- print.step_impute_mean
-
 #' @rdname tidy.recipe
 #' @export
 tidy.step_impute_mean <- function(x, ...) {
@@ -241,10 +196,6 @@ tidy.step_impute_mean <- function(x, ...) {
   res
 }
 
-#' @export
-#' @keywords internal
-tidy.step_meanimpute <- tidy.step_impute_mean
-
 #' @export
 tunable.step_impute_mean <- function(x, ...) {
   tibble::tibble(
@@ -257,7 +208,3 @@ tunable.step_impute_mean <- function(x, ...) {
     component_id = x$id
   )
 }
-
-#' @export
-#' @keywords internal
-tunable.step_meanimpute <- tunable.step_impute_mean
