@@ -20,9 +20,14 @@
 #'
 #' # Tidying
 #'
-#' When you [`tidy()`][tidy.recipe()] this step, a tibble with
-#' columns `terms` (the selectors or variables selected) and `model`
-#' (themedian value) is returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms`, `value` , and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{value}{numeric, the median value}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' @template case-weights-unsupervised
 #'
@@ -46,7 +51,7 @@
 #'
 #' imp_models <- prep(impute_rec, training = credit_tr)
 #'
-#' imputed_te <- bake(imp_models, new_data = credit_te, everything())
+#' imputed_te <- bake(imp_models, new_data = credit_te)
 #'
 #' credit_te[missing_examples, ]
 #' imputed_te[missing_examples, names(credit_te)]
@@ -75,32 +80,6 @@ step_impute_median <-
     )
   }
 
-#' @rdname step_impute_median
-#' @export
-step_medianimpute <-
-  function(recipe,
-           ...,
-           role = NA,
-           trained = FALSE,
-           medians = NULL,
-           skip = FALSE,
-           id = rand_id("impute_median")) {
-    lifecycle::deprecate_stop(
-      when = "0.1.16",
-      what = "recipes::step_medianimpute()",
-      with = "recipes::step_impute_median()"
-    )
-    step_impute_median(
-      recipe,
-      ...,
-      role = role,
-      trained = trained,
-      medians = medians,
-      skip = skip,
-      id = id
-    )
-  }
-
 step_impute_median_new <-
   function(terms, role, trained, medians, skip, id, case_weights) {
     step(
@@ -140,10 +119,6 @@ prep.step_impute_median <- function(x, training, info = NULL, ...) {
   )
 }
 
-#' @export
-#' @keywords internal
-prep.step_medianimpute <- prep.step_impute_median
-
 #' @export
 bake.step_impute_median <- function(object, new_data, ...) {
   col_names <- names(object$medians)
@@ -160,10 +135,6 @@ bake.step_impute_median <- function(object, new_data, ...) {
   new_data
 }
 
-#' @export
-#' @keywords internal
-bake.step_medianimpute <- bake.step_impute_median
-
 #' @export
 print.step_impute_median <-
   function(x, width = max(20, options()$width - 30), ...) {
@@ -173,10 +144,6 @@ print.step_impute_median <-
     invisible(x)
   }
 
-#' @export
-#' @keywords internal
-print.step_medianimpute <- print.step_impute_median
-
 #' @rdname tidy.recipe
 #' @export
 tidy.step_impute_median <- function(x, ...) {
@@ -192,7 +159,3 @@ tidy.step_impute_median <- function(x, ...) {
   res$id <- x$id
   res
 }
-
-#' @export
-#' @keywords internal
-tidy.step_medianimpute <- tidy.step_impute_median
