@@ -85,15 +85,9 @@ step_impute_roll <-
            trained = FALSE,
            columns = NULL,
            statistic = median,
-           window = 5,
+           window = 5L,
            skip = FALSE,
            id = rand_id("impute_roll")) {
-    if (!is_tune(window)) {
-      if (window < 3 | window %% 2 != 1) {
-        cli::cli_abort("{.arg window} should be an odd integer >= 3.")
-      }
-      window <- as.integer(floor(window))
-    }
 
     add_step(
       recipe,
@@ -110,36 +104,6 @@ step_impute_roll <-
     )
   }
 
-#' @rdname step_impute_roll
-#' @export
-step_rollimpute <-
-  function(recipe,
-           ...,
-           role = NA,
-           trained = FALSE,
-           columns = NULL,
-           statistic = median,
-           window = 5,
-           skip = FALSE,
-           id = rand_id("impute_roll")) {
-    lifecycle::deprecate_stop(
-      when = "0.1.16",
-      what = "recipes::step_rollimpute()",
-      with = "recipes::step_impute_roll()"
-    )
-    step_impute_roll(
-      recipe,
-      ...,
-      role = role,
-      trained = trained,
-      columns = columns,
-      statistic = statistic,
-      window = window,
-      skip = skip,
-      id = id
-    )
-  }
-
 step_impute_roll_new <-
   function(terms, role, trained, columns, statistic, window, skip, id) {
     step(
@@ -159,6 +123,12 @@ step_impute_roll_new <-
 prep.step_impute_roll <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names], types = "double")
+  check_function(x$statistic, arg = "statistic", )
+  check_number_whole(x$window, arg = "window", min = 3)
+  if (x$window %% 2 != 1) {
+    cli::cli_abort("{.arg window} should be an odd integer >= 3.")
+  }
+  x$window <- as.integer(x$window)
 
   step_impute_roll_new(
     terms = x$terms,
@@ -172,10 +142,6 @@ prep.step_impute_roll <- function(x, training, info = NULL, ...) {
   )
 }
 
-#' @export
-#' @keywords internal
-prep.step_rollimpute <- prep.step_impute_roll
-
 get_window_ind <- function(i, n, k) {
   sides <- (k - 1) / 2
   if (i - sides >= 1 & i + sides <= n) {
@@ -235,10 +201,6 @@ bake.step_impute_roll <- function(object, new_data, ...) {
   new_data
 }
 
-#' @export
-#' @keywords internal
-bake.step_rollimpute <- bake.step_impute_roll
-
 #' @export
 print.step_impute_roll <-
   function(x, width = max(20, options()$width - 30), ...) {
@@ -247,10 +209,6 @@ print.step_impute_roll <-
     invisible(x)
   }
 
-#' @export
-#' @keywords internal
-print.step_rollimpute <- print.step_impute_roll
-
 #' @rdname tidy.recipe
 #' @export
 tidy.step_impute_roll <- function(x, ...) {
@@ -264,10 +222,6 @@ tidy.step_impute_roll <- function(x, ...) {
   res
 }
 
-#' @export
-#' @keywords internal
-tidy.step_rollimpute <- tidy.step_impute_roll
-
 #' @export
 tunable.step_impute_roll <- function(x, ...) {
   tibble::tibble(
@@ -281,7 +235,3 @@ tunable.step_impute_roll <- function(x, ...) {
     component_id = x$id
   )
 }
-
-#' @export
-#' @keywords internal
-tunable.step_rollimpute <- tunable.step_impute_roll
