@@ -31,9 +31,14 @@
 #'
 #' # Tidying
 #'
-#' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
-#' `terms` (the selectors or variables selected) and `value`
-#' (a _list column_ with the conversion key) is returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms`, `value` , and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{value}{list, a _list column_ with the conversion key}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' @template case-weights-not-supported
 #'
@@ -116,6 +121,8 @@ prep.step_integer <- function(x, training, info = NULL, ...) {
     types = c("string", "factor", "ordered", "integer", "double", "logical",
               "date", "datetime")
   )
+  check_bool(x$strict, arg = "strict")
+  check_bool(x$zero_based, arg = "zero_based")
 
   step_integer_new(
     terms = x$terms,
@@ -166,6 +173,7 @@ bake.step_integer <- function(object, new_data, ...) {
   new_data
 }
 
+#' @export
 print.step_integer <-
   function(x, width = max(20, options()$width - 20), ...) {
     title <- "Integer encoding for "
