@@ -1,4 +1,4 @@
-#' Isomap Embedding
+#' Isomap embedding
 #'
 #' `step_isomap()` creates a *specification* of a recipe step that uses
 #' multidimensional scaling to convert numeric data into one or more new
@@ -11,8 +11,8 @@
 #'  or the number of possible dimensions, a smaller value will be
 #'  used.
 #' @param neighbors The number of neighbors.
-#' @param options A list of options to [dimRed::Isomap()].
-#' @param res The [dimRed::Isomap()] object is stored
+#' @param options A list of options to `dimRed::Isomap()``.
+#' @param res The `dimRed::Isomap()`` object is stored
 #'  here once this preprocessing step has be trained by
 #'  [prep()].
 #' @template step-return
@@ -45,8 +45,13 @@
 #'
 #' # Tidying
 #'
-#' When you [`tidy()`][tidy.recipe()] this step, a tibble with column
-#' `terms` (the selectors or variables selected) is returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms`  , and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' ```{r, echo = FALSE, results="asis"}
 #' step <- "step_isomap"
@@ -150,6 +155,8 @@ step_isomap_new <-
 prep.step_isomap <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names], types = c("double", "integer"))
+  check_number_whole(x$neighbors, arg = "neighbors", min = 1)
+  check_string(x$prefix, arg = "prefix")
 
   if (x$num_terms > 0 && length(col_names) > 0L) {
     x$num_terms <- min(x$num_terms, ncol(training))
@@ -168,7 +175,10 @@ prep.step_isomap <- function(x, training, info = NULL, ...) {
         silent = TRUE
       )
     if (inherits(iso_map, "try-error")) {
-      rlang::abort(paste0("`step_isomap` failed with error:\n", as.character(iso_map)))
+      cli::cli_abort(c(
+        x = "Failed with error:",
+        i = as.character(iso_map)
+      ))
     }
   } else {
     iso_map <- NULL
@@ -211,7 +221,7 @@ bake.step_isomap <- function(object, new_data, ...) {
   new_data
 }
 
-
+#' @export
 print.step_isomap <- function(x, width = max(20, options()$width - 35), ...) {
   if (x$num_terms == 0) {
     title <- "Isomap was not conducted for "
