@@ -1,4 +1,4 @@
-#' Polynomial Kernel PCA Signal Extraction
+#' Polynomial kernel PCA signal extraction
 #'
 #' `step_kpca_poly()` creates a *specification* of a recipe step that will
 #' convert numeric data into one or more principal components using a polynomial
@@ -6,7 +6,8 @@
 #'
 #' @inheritParams step_pca
 #' @inheritParams step_center
-#' @param degree,scale_factor,offset Numeric values for the polynomial kernel function.
+#' @param degree,scale_factor,offset Numeric values for the polynomial kernel
+#' function. See the documentation at [kernlab::polydot()].
 #' @param res An S4 [kernlab::kpca()] object is stored
 #'  here once this preprocessing step has be trained by
 #'  [prep()].
@@ -23,6 +24,16 @@
 #' cat(result)
 #' ```
 #'
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms` and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{id}{character, id of this step}
+#' }
+#'
 #' @template case-weights-not-supported
 #'
 #' @examplesIf rlang::is_installed(c("modeldata", "ggplot2","kernlab"))
@@ -114,6 +125,11 @@ step_kpca_poly_new <-
 prep.step_kpca_poly <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names], types = c("double", "integer"))
+  check_number_whole(x$degree, arg = "degree", min = 1)
+  check_number_decimal(x$scale_factor, arg = "scale_factor", min = 0)
+  check_number_decimal(x$offset, arg = "offset")
+  check_string(x$prefix, arg = "prefix")
+  check_number_whole(x$num_comp, arg = "num_comp", min = 0)
 
   if (x$num_comp > 0 && length(col_names) > 0) {
     cl <-
@@ -131,7 +147,10 @@ prep.step_kpca_poly <- function(x, training, info = NULL, ...) {
       )
     kprc <- try(rlang::eval_tidy(cl), silent = TRUE)
     if (inherits(kprc, "try-error")) {
-      rlang::abort(paste0("`step_kpca_poly` failed with error:\n", as.character(kprc)))
+      cli::cli_abort(c(
+        x = "Failed with error:",
+        i = as.character(kprc)
+      ))
     }
   } else {
     kprc <- NULL
@@ -182,6 +201,7 @@ bake.step_kpca_poly <- function(object, new_data, ...) {
   new_data
 }
 
+#' @export
 print.step_kpca_poly <- function(x, width = max(20, options()$width - 40), ...) {
   title <- "Polynomial kernel PCA extraction with "
   print_step(x$columns, x$terms, x$trained, title, width)
