@@ -1,4 +1,4 @@
-#' Radial Basis Function Kernel PCA Signal Extraction
+#' Radial basis function kernel PCA signal extraction
 #'
 #' `step_kpca_rbf()` creates a *specification* of a recipe step that will
 #' convert numeric data into one or more principal components using a radial
@@ -6,7 +6,8 @@
 #'
 #' @inheritParams step_pca
 #' @inheritParams step_center
-#' @param sigma A numeric value for the radial basis function parameter.
+#' @param sigma A numeric value for the radial basis function parameter. See
+#' the documentation at [kernlab::rbfdot()].
 #' @param res An S4 [kernlab::kpca()] object is stored
 #'  here once this preprocessing step has be trained by
 #'  [prep()].
@@ -23,6 +24,16 @@
 #' cat(result)
 #' ```
 #'
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms` and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{id}{character, id of this step}
+#' }
+#'
 #' @template case-weights-not-supported
 #'
 #' @examplesIf rlang::is_installed(c("modeldata", "ggplot2", "kernlab"))
@@ -108,6 +119,9 @@ step_kpca_rbf_new <-
 prep.step_kpca_rbf <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names], types = c("double", "integer"))
+  check_number_decimal(x$sigma, arg = "sigma", min = .Machine$double.eps)
+  check_string(x$prefix, arg = "prefix")
+  check_number_whole(x$num_comp, arg = "num_comp", min = 0)
 
   if (x$num_comp > 0 && length(col_names) > 0) {
     cl <-
@@ -121,7 +135,10 @@ prep.step_kpca_rbf <- function(x, training, info = NULL, ...) {
       )
     kprc <- try(rlang::eval_tidy(cl), silent = TRUE)
     if (inherits(kprc, "try-error")) {
-      rlang::abort(paste0("`step_kpca_rbf` failed with error:\n", as.character(kprc)))
+      cli::cli_abort(c(
+        x = "Failed with error:",
+        i = as.character(kprc)
+      ))
     }
   } else {
     kprc <- NULL
@@ -170,6 +187,7 @@ bake.step_kpca_rbf <- function(object, new_data, ...) {
   new_data
 }
 
+#' @export
 print.step_kpca_rbf <- function(x, width = max(20, options()$width - 40), ...) {
   title <- "RBF kernel PCA extraction with "
   print_step(x$columns, x$terms, x$trained, title, width)
