@@ -108,6 +108,9 @@ step_log_new <-
 prep.step_log <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names], types = c("double", "integer"))
+  check_number_decimal(x$offset, arg = "offset")
+  check_bool(x$signed, arg = "signed")
+  check_number_decimal(x$base, arg = "base", min = 0)
 
   step_log_new(
     terms = x$terms,
@@ -156,6 +159,7 @@ bake.step_log <- function(object, new_data, ...) {
   new_data
 }
 
+#' @export
 print.step_log <-
   function(x, width = max(20, options()$width - 31), ...) {
     msg <- ifelse(x$signed, "Signed log", "Log")
