@@ -1,4 +1,4 @@
-#' Logit Transformation
+#' Logit transformation
 #'
 #' `step_logit()` creates a *specification* of a recipe step that will logit
 #' transform the data.
@@ -14,10 +14,15 @@
 #'  zero and one and translates them to be on the real line using
 #'  the function `f(p) = log(p/(1-p))`.
 #'
-#'  # Tidying
+#' # Tidying
 #'
-#'  When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
-#'  `terms` (the columns that will be affected) is returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms` and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' @template case-weights-not-supported
 #'
@@ -79,6 +84,7 @@ step_logit_new <-
 prep.step_logit <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names], types = c("double", "integer"))
+  check_number_decimal(x$offset, arg = "offset")
 
   step_logit_new(
     terms = x$terms,
@@ -110,7 +116,7 @@ bake.step_logit <- function(object, new_data, ...) {
   new_data
 }
 
-
+#' @export
 print.step_logit <-
   function(x, width = max(20, options()$width - 33), ...) {
     title <- "Logit transformation on "
