@@ -21,13 +21,30 @@ get_rhs_vars <- function(formula, data, no_lhs = FALSE) {
   ## or should it? what about Y ~ log(x)?
   ## Answer: when called from `form2args`, the function
   ## `inline_check` stops when in-line functions are used.
-  data_info <- attr(model.frame(formula, data[1, ]), "terms")
-  response_info <- attr(data_info, "response")
-  predictor_names <- names(attr(data_info, "dataClasses"))
-  if (length(response_info) > 0 && all(response_info > 0)) {
-    predictor_names <- predictor_names[-response_info]
+
+  outcomes_names <- all.names(
+    rlang::f_lhs(formula),
+    functions = FALSE,
+    unique = TRUE
+  )
+
+  predictors_names <- all.names(
+    rlang::f_rhs(formula),
+    functions = FALSE,
+    unique = TRUE
+  )
+
+  if (any(predictors_names == ".")) {
+    predictors_names <- predictors_names[predictors_names != "."]
+    predictors_names <- c(predictors_names, colnames(data))
+    predictors_names <- unique(predictors_names)
   }
-  predictor_names
+
+  if (length(predictors_names) > 0 && length(outcomes_names) > 0) {
+    predictors_names <- setdiff(predictors_names, outcomes_names)
+  }
+
+  predictors_names
 }
 
 #' Naming Tools
@@ -48,7 +65,10 @@ get_rhs_vars <- function(formula, data, no_lhs = FALSE) {
 #' @param ordinal A logical; was the original factor ordered?
 #' @param sep A single character value for the separator between the names and
 #'  levels.
-#'
+#' @param call The execution environment of a currently running function, e.g.
+#'   `caller_env()`. The function will be mentioned in error messages as the
+#'   source of the error. See the call argument of [rlang::abort()] for more
+#'   information.
 #' @details When using `dummy_names()`, factor levels that are not valid
 #'  variable names (e.g. "some text  with spaces") will be changed to valid
 #'  names by [base::make.names()]; see example below. This function will also
@@ -81,10 +101,8 @@ get_rhs_vars <- function(formula, data, no_lhs = FALSE) {
 #'
 #' dummy_names("x", substring(after_mm, 2), ordinal = TRUE)
 #' @export
-names0 <- function(num, prefix = "x") {
-  if (num < 1) {
-    rlang::abort("`num` should be > 0.")
-  }
+names0 <- function(num, prefix = "x", call = rlang::caller_env()) {
+  check_number_whole(num, min = 1, call = call)
   ind <- format(seq_len(num))
   ind <- gsub(" ", "0", ind)
   paste0(prefix, ind)
@@ -136,25 +154,10 @@ dummy_extract_names <- function(var, lvl, ordinal = FALSE, sep = "_") {
   nms
 }
 
-
-## As suggested by HW, brought in from the `pryr` package
-## https://github.com/hadley/pryr
-fun_calls <- function(f) {
-  if (is.function(f)) {
-    fun_calls(body(f))
-  } else if (is_quosure(f)) {
-    fun_calls(quo_get_expr(f))
-  } else if (is.call(f)) {
-    fname <- as.character(f[[1]])
-    # Calls inside .Internal are special and shouldn't be included
-    if (identical(fname, ".Internal")) {
-      return(fname)
-    }
-    unique(c(fname, unlist(lapply(f[-1], fun_calls), use.names = FALSE)))
-  }
+fun_calls <- function(f, data) {
+  setdiff(all.names(f), colnames(data))
 }
 
-
 get_levels <- function(x) {
   if (!is.factor(x) & !is.character(x)) {
     return(list(values = NA, ordered = NA))
@@ -180,6 +183,20 @@ has_lvls <- function(info) {
   !vapply(info, function(x) all(is.na(x$values)), c(logic = TRUE))
 }
 
+kill_levels <- function(lvls, var_info) {
+  vars <- var_info$variable
+  roles <- var_info$role
+  preds_outcomes <- unique(vars[roles %in% c("outcome", "predictor")])
+  others <- unique(setdiff(vars, preds_outcomes))
+  if (length(others) > 0L) {
+    for (var in others) {
+      lvls[[var]] <- list(values = NA, ordered = NA)
+    }
+  }
+  lvls
+}
+
+
 strings2factors <- function(x, info) {
   check_lvls <- has_lvls(info)
   if (!any(check_lvls)) {
@@ -191,9 +208,11 @@ strings2factors <- function(x, info) {
   for (i in seq_along(info)) {
     lcol <- names(info)[i]
     x[, lcol] <-
-      factor(as.character(x[[lcol]]),
+      factor(
+        as.character(x[[lcol]]),
         levels = info[[i]]$values,
-        ordered = info[[i]]$ordered
+        ordered = info[[i]]$ordered,
+        exclude = NULL
       )
   }
   x
@@ -202,7 +221,7 @@ strings2factors <- function(x, info) {
 
 # ------------------------------------------------------------------------------
 
-# `complete.cases` fails on list columns. This version counts a list column
+# `vec_detect_complete` fails on list columns. This version counts a list column
 # as missing if _all_ values are missing. For if a list vector element is a
 # data frame with one missing value, that element of the list column will
 # be counted as complete.
@@ -214,7 +233,19 @@ n_complete_rows <- function(x) {
     x[[pos_list_col]] <- purrr::map_lgl(x[[pos_list_col]], flatten_na)
   }
 
-  sum(complete.cases(x))
+  x <- x[, vapply(x, anyNA, logical(1))]
+
+  surv_col_ind <- purrr::map_lgl(x, inherits, "Surv")
+  if (any(surv_col_ind)) {
+    surv_cols <- stats::complete.cases(x[, surv_col_ind, drop = FALSE])
+    non_surv_cols <- vec_detect_complete(x[, !surv_col_ind, drop = FALSE])
+
+    res <- sum(surv_cols & non_surv_cols)
+  } else {
+    res <- sum(vec_detect_complete(x))
+  }
+
+  res
 }
 
 flatten_na <- function(x) {
@@ -262,18 +293,22 @@ merge_term_info <- function(.new, .old) {
 #' `ellipse_check()` is deprecated. Instead, empty selections should be
 #' supported by all steps.
 #'
-#' @param ... Arguments pass in from a call to `step`
-#' @return If not empty, a list of quosures. If empty, an error is thrown.
-#' @export
+#' @param ... Arguments pass in from a call to `step`.
+#'
+#' @return `ellipse_check()`: If not empty, a list of quosures. If empty, an
+#'   error is thrown.
+#'
 #' @keywords internal
 #' @rdname recipes-internal
+#' @export
 ellipse_check <- function(...) {
   terms <- quos(...)
   if (is_empty(terms)) {
-    rlang::abort(
-      paste0(
-        "Please supply at least one variable specification.",
-        "See ?selections."
+    cli::cli_abort(
+      c(
+        "!" = "Please supply at least one variable specification.",
+        "i" = "See {.help [?selections](recipes::selections)} \\
+              for more information."
       )
     )
   }
@@ -282,7 +317,7 @@ ellipse_check <- function(...) {
 
 #' Printing Workhorse Function
 #'
-#' This internal function is used for printing steps.
+#' `printer()` is used for printing steps.
 #'
 #' @param tr_obj A character vector of names that have been
 #'  resolved during preparing the recipe (e.g. the `columns` object
@@ -291,10 +326,12 @@ ellipse_check <- function(...) {
 #'  recipe (e.g. `terms` in most steps).
 #' @param trained A logical for whether the step has been trained.
 #' @param width An integer denoting where the output should be wrapped.
-#' @return `NULL`, invisibly.
+#'
+#' @return `printer()`: `NULL`, invisibly.
+#'
 #' @keywords internal
-#' @export
 #' @rdname recipes-internal
+#' @export
 printer <- function(tr_obj = NULL,
                     untr_obj = NULL,
                     trained = FALSE,
@@ -321,14 +358,13 @@ printer <- function(tr_obj = NULL,
 }
 
 
-#' @export
 #' @keywords internal
 #' @rdname recipes-internal
+#' @export
 prepare <- function(x, ...) {
-  rlang::abort(paste0(
-    "As of version 0.0.1.9006, used `prep` ",
-    "instead of `prepare`"
-  ))
+  cli::cli_abort(
+    "As of version 0.0.1.9006 please use {.fn prep} instead of {.fn prepare}."
+  )
 }
 
 
@@ -425,24 +461,52 @@ check_type <- function(dat, quant = TRUE, types = NULL, call = caller_env()) {
   if (is.null(types)) {
     if (quant) {
       all_good <- vapply(dat, is.numeric, logical(1))
-      label <- "numeric"
+      types <- "numeric"
     } else {
       all_good <- vapply(dat, is_qual, logical(1))
-      label <- "factor or character"
+      types <- "factor or character"
     }
   } else {
     all_good <- purrr::map_lgl(get_types(dat)$type, ~ any(.x %in% types))
-    label <- glue::glue_collapse(types, sep = ", ", last = ", or ")
   }
 
   if (!all(all_good)) {
-    rlang::abort(
-      paste0(
-        "All columns selected for the step",
-        " should be ",
-        label,
-        "."
-      ),
+    info <- get_types(dat)[!all_good, ]
+    classes <- map_chr(info$type, function(x) x[1])
+    counts <- vctrs::vec_split(info$variable, classes)
+    counts$count <- lengths(counts$val)
+    counts$text_len <- cli::console_width() - 18 - (counts$count > 1) -
+      nchar(counts$key) - (counts$count > 2)
+
+    # cli::ansi_collapse() doesn't work for length(x) == 1
+    # https://github.com/r-lib/cli/issues/590
+    variable_collapse <- function(x, width) {
+      x <- paste0("{.var ", x, "}")
+      if (length(x) == 1) {
+        res <- cli::ansi_strtrim(x, width = width)
+      } else if (length(x) == 2) {
+        res <- cli::ansi_collapse(
+          x, last = " and ", width = width, style = "head"
+        )
+      } else {
+        res <- cli::ansi_collapse(
+          x, width = width, style = "head"
+        )
+      }
+      res
+    }
+
+    problems <- glue::glue_data(
+      counts,
+      "{count} {key} variable{ifelse(count == 1, '', 's')} \\
+      found: {purrr::map2_chr(val, text_len, variable_collapse)}"
+    )
+    names(problems) <- rep("*", length(problems))
+
+    message <- "All columns selected for the step should be {.or {types}}."
+
+    cli::cli_abort(
+      c("x" = message, problems),
       call = call
     )
   }
@@ -453,12 +517,18 @@ check_type <- function(dat, quant = TRUE, types = NULL, call = caller_env()) {
 ## Support functions
 
 #' Check to see if a step or check as been trained
+#'
+#' `is_trained()` is a helper function that returned a single logical to
+#' indicate whether a recipe is traine or not.
+#'
 #' @param x a step object.
-#' @return A logical
-#' @export
-#' @keywords internal
-#' @rdname recipes-internal
+#' @return `is_trained()`: A single logical.
+#'
 #' @seealso [developer_functions]
+#' @keywords internal
+#'
+#' @rdname recipes-internal
+#' @export
 is_trained <- function(x) {
   x$trained
 }
@@ -466,15 +536,17 @@ is_trained <- function(x) {
 
 #' Convert Selectors to Character
 #'
-#' This internal function takes a list of selectors (e.g. `terms`
-#'  in most steps) and returns a character vector version for
-#'  printing.
+#' `sel2char()` takes a list of selectors (e.g. `terms` in most steps) and
+#' returns a character vector version for printing.
+#'
 #' @param x A list of selectors
-#' @return A character vector
-#' @export
+#' @return `sel2char()`: A character vector.
+#'
+#' @seealso [developer_functions]
+#'
 #' @keywords internal
 #' @rdname recipes-internal
-#' @seealso [developer_functions]
+#' @export
 sel2char <- function(x) {
   unname(map_chr(x, to_character))
 }
@@ -530,8 +602,8 @@ check_name <- function(res, new_data, object, newname = NULL, names = FALSE,
   if (any(intersection)) {
     nms <- new_data_names[intersection]
     cli::cli_abort(
-      c("Name collision occured. The following variable names already exists:",
-        i = " {nms}"),
+      c("Name collision occurred. The following variable names already exist:",
+        "*" = "{.var {nms}}"),
       call = call
     )
 
@@ -564,7 +636,7 @@ rand_id <- function(prefix = "step", len = 5) {
 }
 
 
-check_nominal_type <- function(x, lvl) {
+check_nominal_type <- function(x, lvl, call = rlang::caller_env()) {
   all_act_cols <- names(x)
 
   # What columns do we expect to be factors based on the data
@@ -589,75 +661,63 @@ check_nominal_type <- function(x, lvl) {
     was_factor <- fac_ref_cols[!(fac_ref_cols %in% fac_act_cols)]
 
     if (length(was_factor) > 0) {
-      rlang::warn(
-        paste0(
-          " There ",
-          ifelse(length(was_factor) > 1, "were ", "was "),
-          length(was_factor),
-          ifelse(length(was_factor) > 1, " columns ", " column "),
-          "that ",
-          ifelse(length(was_factor) > 1, "were factors ", "was a factor "),
-          "when the recipe was prepped:\n ",
-          paste0("'", was_factor, "'", collapse = ", "),
-          ".\n This may cause errors when processing new data."
-        )
+      cli::cli_warn(
+        c(
+          "!" = "There {?w/was/were} {length(was_factor)} column{?s} that \\
+                {?was a factor/were factors} when the recipe was prepped: \\
+                ",
+          "*" = "{.and {.var {was_factor}}}",
+          "i" = "This may cause errors when processing new data."
+        ),
+        call = call
       )
     }
   }
   invisible(NULL)
 }
 
-check_training_set <- function(x, rec, fresh) {
-  # In case a variable has multiple roles
-  vars <- unique(rec$var_info$variable)
-
-  if (is.null(x)) {
+validate_training_data <- function(x, rec, fresh, call = rlang::caller_env()) {
+  training_null <- is.null(x)
+  if (training_null) {
     if (fresh) {
-      rlang::abort(
-        paste0(
-          "A training set must be supplied to the `training` argument ",
-          "when `fresh = TRUE`."
-        )
+      cli::cli_abort(
+        "A training set must be supplied to the {.arg training} argument \\
+        when {.code fresh = TRUE}.",
+        call = call
       )
     }
     x <- rec$template
   } else {
-    in_data <- vars %in% colnames(x)
-    if (!all(in_data)) {
-      rlang::abort(
-        paste0(
-          "Not all variables in the recipe are present in the supplied ",
-          "training set: ",
-          paste0("'", vars[!in_data], "'", collapse = ", "),
-          "."
-        )
-      )
+    if (is_sparse_matrix(x)) {
+      x <- sparsevctrs::coerce_to_sparse_tibble(x, call = call)
     }
     if (!is_tibble(x)) {
-      x <- as_tibble(x[, vars, drop = FALSE])
-    } else {
-      x <- x[, vars]
+      x <- as_tibble(x)
     }
+    recipes_ptype_validate(rec, new_data = x, stage = "prep", call = call)
+
+    # In case a variable has multiple roles
+    vars <- unique(rec$var_info$variable)
+    x <- x[, vars]
   }
 
   steps_trained <- vapply(rec$steps, is_trained, logical(1))
   if (any(steps_trained) & !fresh) {
     if (!rec$retained) {
-      rlang::abort(
-        paste0(
-          "To prep new steps after prepping the original ",
-          "recipe, `retain = TRUE` must be set each time that ",
-          "the recipe is trained."
-        )
+      cli::cli_abort(
+        "To prep new steps after prepping the original recipe, \\
+        {.code retain = TRUE} must be set each time that the recipe is \\
+        trained.",
+        call = call
       )
     }
-    if (!is.null(rec$training)) {
-      rlang::warn(
-        paste0(
-          "The previous data will be used by `prep`; ",
-          "the data passed using `training` will be ",
-          "ignored."
-        )
+    if (!training_null) {
+      cli::cli_warn(
+        c(
+          "!" = "The previous data will be used by {.fn prep}.",
+          "i" = "The data passed using {.arg training} will be ignored."
+        ),
+        call = call
       )
     }
     x <- rec$template
@@ -678,12 +738,11 @@ get_keep_original_cols <- function(object) {
 
   if (is.null(object$keep_original_cols)) {
     ret <- FALSE
-    rlang::warn(
-      paste0(
-        "'keep_original_cols' was added to `",
-        step_class,
-        "()` after this recipe was created.\n",
-        "Regenerate your recipe to avoid this warning."
+    cli::cli_warn(
+      c(
+        "{.arg keep_original_cols} was added to {.fn {step_class}} after this \\
+         recipe was created.",
+        "i" = "Regenerate your recipe to avoid this warning."
       )
     )
   } else {
@@ -780,11 +839,10 @@ dimred_data <- function(dat) {
 uses_dim_red <- function(x) {
   dr <- inherits(x, "dimRedResult")
   if (dr) {
-    rlang::abort(
-      paste(
-        "Recipes version >= 0.1.17 represents the estimates using a different format.",
-        "Please recreate this recipe or use version 0.1.16 or less. See issue #823."
-      )
+    cli::cli_abort(
+      "Recipes version >= 0.1.17 represents the estimates using a different \\
+      format. Please recreate this recipe or use version 0.1.16 or less. See \\
+      issue {.href [#823](https://github.com/tidymodels/recipes/issues/823)}."
     )
   }
   invisible(NULL)
@@ -817,9 +875,8 @@ check_new_data <- function(req, object, new_data) {
   step_cls <- class(object)[1]
   step_id <- object$id
   cli::cli_abort(
-    "The following required {cli::qty(col_diff)} column{?s} {?is/are} \
-    missing from `new_data` in step '{step_id}': {col_diff}.",
-    class = "new_data_missing_column",
+    "The following required {cli::qty(col_diff)} column{?s} {?is/are} missing
+    from {.arg new_data}: {col_diff}.",
     call = rlang::call2(step_cls)
   )
 }
@@ -920,3 +977,36 @@ recipes_remove_cols <- function(new_data, object, col_names = character()) {
   }
   new_data
 }
+
+#' Role indicators
+#'
+#' This helper function is meant to be used in `prep()` methods to identify
+#' predictors and outcomes by names.
+#'
+#' @param info data.frame with variable information of columns.
+#'
+#' @return Character vector of column names.
+#' @keywords internal
+#'
+#' @seealso [developer_functions]
+#'
+#' @name recipes-role-indicator
+NULL
+
+#' @rdname recipes-role-indicator
+#' @export
+recipes_names_predictors <- function(info) {
+  get_from_info(info, "predictor")
+}
+
+#' @rdname recipes-role-indicator
+#' @export
+recipes_names_outcomes <- function(info) {
+  get_from_info(info, "outcome")
+}
+
+get_from_info <- function(info, role) {
+  res <- info$variable[info$role == role & !is.na(info$role)]
+
+  res
+}
