@@ -16,8 +16,13 @@
 #'
 #' # Tidying
 #'
-#' When you [`tidy()`][tidy.recipe()] this step, a tibble with column
-#' `terms` which contains the columns being transformed is returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms` and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' @template case-weights-not-supported
 #'
@@ -46,6 +51,10 @@ step_mutate_at <- function(recipe, ...,
                            inputs = NULL,
                            skip = FALSE,
                            id = rand_id("mutate_at")) {
+  if (rlang::is_missing(fn)) {
+    cli::cli_abort("Argument {.arg fn} must be specified.")
+  }
+
   add_step(
     recipe,
     step_mutate_at_new(
@@ -94,7 +103,7 @@ bake.step_mutate_at <- function(object, new_data, ...) {
   dplyr::mutate_at(new_data, .vars = object$inputs, .funs = object$fn)
 }
 
-
+#' @export
 print.step_mutate_at <-
   function(x, width = max(20, options()$width - 35), ...) {
     title <- "Variable mutation for "
