@@ -1,4 +1,4 @@
-#' Check for New Values
+#' Check for new values
 #'
 #' `check_new_values` creates a *specification* of a recipe
 #'  operation that will check if variables contain new values.
@@ -107,16 +107,16 @@ new_values_func <- function(x,
     return()
   }
   if (ignore_NA) new_vals <- new_vals[!is.na(new_vals)]
-  rlang::abort(paste0(
-    colname,
-    " contains the new value(s): ",
-    paste(new_vals, collapse = ",")
-  ))
+  cli::cli_abort(
+    "{.var {colname}} contains the new \\
+    {cli::qty(length(new_vals))}value{?s}: {.val {new_vals}}."
+  )
 }
 
 #' @export
 prep.check_new_values <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
+  check_bool(x$ignore_NA, arg = "ignore_NA")
 
   values <- lapply(training[, col_names], unique)
 
@@ -148,6 +148,7 @@ bake.check_new_values <- function(object, new_data, ...) {
   new_data
 }
 
+#' @export
 print.check_new_values <-
   function(x, width = max(20, options()$width - 30), ...) {
     title <- "Checking no new_values for "
