@@ -1,4 +1,4 @@
-#' Non-Negative Matrix Factorization Signal Extraction with lasso Penalization
+#' Non-negative matrix factorization signal extraction with lasso penalization
 #'
 #' `step_nnmf_sparse()` creates a *specification* of a recipe step that will
 #' convert numeric data into one or more non-negative components.
@@ -29,11 +29,17 @@
 #' cat(result)
 #' ```
 #'
-#'  # Tidying
+#' # Tidying
 #'
-#'  When you [`tidy()`][tidy.recipe()] this step, a tibble with column
-#'  `terms` (the selectors or variables selected) and the number of
-#'  components is returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms`, `value`, `component` , and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{value}{numeric, value of loading}
+#'   \item{component}{character, name of component}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' ```{r, echo = FALSE, results="asis"}
 #' step <- "step_nnmf_sparse"
@@ -148,6 +154,9 @@ nnmf_pen_call <- function(x) {
 prep.step_nnmf_sparse <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names], types = c("double", "integer"))
+  check_number_whole(x$num_comp, arg = "num_comp", min = 0)
+  check_number_decimal(x$penalty, arg = "penalty", min = .Machine$double.eps)
+  check_string(x$prefix, arg = "prefix")
 
   if (x$num_comp > 0 && length(col_names) > 0) {
     x$num_comp <- min(x$num_comp, length(col_names))
@@ -157,11 +166,17 @@ prep.step_nnmf_sparse <- function(x, training, info = NULL, ...) {
     nnm <- try(rlang::eval_tidy(cl), silent = TRUE)
 
     if (inherits(nnm, "try-error")) {
-      rlang::abort(paste0("`step_nnmf_sparse` failed with error:\n", as.character(nnm)))
+      cli::cli_abort(c(
+        x = "Failed with error:",
+        i = as.character(nnm)
+      ))
     } else {
       na_w <- sum(is.na(nnm$w))
       if (na_w > 0) {
-        rlang::abort("The NNMF loadings are missing. The penalty may have been to high.")
+        cli::cli_abort(c(
+          x = "The NNMF loadings are missing.",
+          i = "The penalty may have been too high or missing values are present in data."
+        ))
       } else {
         nnm <- list(x_vars = col_names, w = nnm$w)
         rownames(nnm$w) <- col_names
@@ -207,7 +222,7 @@ bake.step_nnmf_sparse <- function(object, new_data, ...) {
   new_data
 }
 
-
+#' @export
 print.step_nnmf_sparse <- function(x, width = max(20, options()$width - 29), ...) {
   if (x$trained) {
     if (x$num_comp == 0) {
