@@ -1,4 +1,4 @@
-#' Near-Zero Variance Filter
+#' Near-zero variance filter
 #'
 #' `step_nzv()` creates a *specification* of a recipe step that will potentially
 #' remove variables that are highly sparse and unbalanced.
@@ -42,8 +42,13 @@
 #'
 #' # Tidying
 #'
-#' When you [`tidy()`][tidy.recipe()] this step, a tibble with column
-#' `terms` (the columns that will be removed) is returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms` and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' ```{r, echo = FALSE, results="asis"}
 #' step <- "step_nzv"
@@ -88,9 +93,8 @@ step_nzv <-
            skip = FALSE,
            id = rand_id("nzv")) {
     exp_list <- list(freq_cut = 95 / 5, unique_cut = 10)
+
     if (!isTRUE(all.equal(exp_list, options))) {
-      freq_cut <- options$freq_cut
-      unique_cut <- options$unique_cut
       lifecycle::deprecate_stop(
         "0.1.7",
         "step_nzv(options)",
@@ -136,6 +140,8 @@ step_nzv_new <-
 #' @export
 prep.step_nzv <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
+  check_number_decimal(x$unique_cut, arg = "unique_cut", min = 0, max = 100)
+  check_number_decimal(x$freq_cut, arg = "freq_cut", min = 0)
 
   wts <- get_case_weights(info, training)
   were_weights_used <- are_weights_used(wts, unsupervised = TRUE)
@@ -170,6 +176,7 @@ bake.step_nzv <- function(object, new_data, ...) {
   new_data
 }
 
+#' @export
 print.step_nzv <-
   function(x, width = max(20, options()$width - 38), ...) {
     if (x$trained) {
