@@ -1,4 +1,4 @@
-#' Convert Ordinal Factors to Numeric Scores
+#' Convert ordinal factors to numeric scores
 #'
 #' `step_ordinalscore()` creates a *specification* of a recipe step that will
 #' convert ordinal factor variables into numeric scores.
@@ -18,10 +18,15 @@
 #'  a linear scale (1, 2, 3, ... `C`) but custom score
 #'  functions can also be used (see the example below).
 #'
-#'  # Tidying
+#' # Tidying
 #'
-#' When you [`tidy()`][tidy.recipe()] this step, a tibble with column
-#' `terms` (the columns that will be affected) is returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms` and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' @template case-weights-not-supported
 #'
@@ -45,7 +50,7 @@
 #'
 #' linear_values <- prep(linear_values, training = ord_data)
 #'
-#' bake(linear_values, new_data = NULL, everything())
+#' bake(linear_values, new_data = NULL)
 #'
 #' custom <- function(x) {
 #'   new_values <- c(1, 3, 7)
@@ -60,7 +65,7 @@
 #'
 #' nonlin_scores <- prep(nonlin_scores, training = ord_data)
 #'
-#' bake(nonlin_scores, new_data = NULL, everything())
+#' bake(nonlin_scores, new_data = NULL)
 #'
 #' tidy(nonlin_scores, number = 2)
 step_ordinalscore <-
@@ -104,6 +109,7 @@ step_ordinalscore_new <-
 prep.step_ordinalscore <- function(x, training, info = NULL, ...) {
     col_names <- recipes_eval_select(x$terms, training, info)
     check_type(training[, col_names], types = "ordered")
+    check_function(x$convert, arg = "convert")
 
     step_ordinalscore_new(
       terms = x$terms,
@@ -130,6 +136,7 @@ bake.step_ordinalscore <- function(object, new_data, ...) {
   new_data
 }
 
+#' @export
 print.step_ordinalscore <-
   function(x, width = max(20, options()$width - 30), ...) {
     title <- "Scoring for "
