@@ -1,4 +1,4 @@
-#' PCA Signal Extraction
+#' PCA signal extraction
 #'
 #' `step_pca()` creates a *specification* of a recipe step that will convert
 #' numeric variables into one or more principal components.
@@ -60,9 +60,26 @@
 #'
 #' # Tidying
 #'
-#' When you [`tidy()`][tidy.recipe()] this step, use either `type = "coef"`
-#' for the variable loadings per component or `type = "variance"` for how
-#' much variance each component accounts for.
+#' When you [`tidy()`][tidy.recipe()] this step two things can happen depending
+#' the `type` argument. If `type = "coef"` a tibble returned with 4 columns
+#' `terms`, `value`, `component` , and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{value}{numeric, variable loading}
+#'   \item{component}{character, principle component}
+#'   \item{id}{character, id of this step}
+#' }
+#'
+#' If `type = "variance"` a tibble returned with 4 columns `terms`, `value`,
+#' `component` , and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, type of variance}
+#'   \item{value}{numeric, value of the variance}
+#'   \item{component}{integer, principle component}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' ```{r, echo = FALSE, results="asis"}
 #' step <- "step_pca"
@@ -96,6 +113,7 @@
 #'
 #' tidy(pca_trans, number = 2)
 #' tidy(pca_estimates, number = 2)
+#' tidy(pca_estimates, number = 2, type = "variance")
 step_pca <- function(recipe,
                      ...,
                      role = "predictor",
@@ -109,11 +127,6 @@ step_pca <- function(recipe,
                      keep_original_cols = FALSE,
                      skip = FALSE,
                      id = rand_id("pca")) {
-  if (!is_tune(threshold)) {
-    if (!is.na(threshold) && (threshold > 1 | threshold <= 0)) {
-      rlang::abort("`threshold` should be on (0, 1].")
-    }
-  }
 
   add_step(
     recipe,
@@ -160,6 +173,10 @@ step_pca_new <-
 prep.step_pca <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names], types = c("double", "integer"))
+  check_number_decimal(x$threshold, arg = "threshold", min = 0, max = 1,
+                       allow_na = TRUE)
+  check_string(x$prefix, arg = "prefix")
+  check_number_whole(x$num_comp, arg = "num_comp", min = 0)
 
   wts <- get_case_weights(info, training)
   were_weights_used <- are_weights_used(wts, unsupervised = TRUE)
@@ -234,14 +251,14 @@ bake.step_pca <- function(object, new_data, ...) {
 
   pca_vars <- rownames(object$res$rotation)
   comps <- scale(new_data[, pca_vars], object$res$center, object$res$scale) %*%
-    object$res$rotation
-  comps <- comps[, seq_len(object$num_comp), drop = FALSE]
+    object$res$rotation[, seq_len(object$num_comp), drop = FALSE]
   comps <- check_name(comps, new_data, object)
   new_data <- vec_cbind(new_data, as_tibble(comps))
   new_data <- remove_original_cols(new_data, object, pca_vars)
   new_data
 }
 
+#' @export
 print.step_pca <-
   function(x, width = max(20, options()$width - 29), ...) {
     if (x$trained) {
@@ -335,7 +352,11 @@ tidy.step_pca <- function(x, type = "coef", ...) {
       component = na_chr
     )
   } else {
-    type <- match.arg(type, c("coef", "variance"))
+    type <- rlang::arg_match(
+      type,
+      c("coef", "variance"),
+      error_call = rlang::caller_env()
+    )
     if (type == "coef") {
       res <- pca_coefs(x)
     } else {
