@@ -1,32 +1,44 @@
-#' Orthogonal Polynomial Basis Functions
+#' Orthogonal polynomial basis functions
 #'
 #' `step_poly()` creates a *specification* of a recipe step that will create new
 #' columns that are basis expansions of variables using orthogonal polynomials.
 #'
 #' @inheritParams step_pca
 #' @inheritParams step_center
-#' @param objects A list of [stats::poly()] objects
-#'  created once the step has been trained.
+#' @param objects A list of [stats::poly()] objects created once the step has
+#'   been trained.
 #' @param degree The polynomial degree (an integer).
-#' @param options A list of options for [stats::poly()]
-#'  which should not include `x`, `degree`, or `simple`. Note that
-#'  the option `raw = TRUE` will produce the regular polynomial
-#'  values (not orthogonalized).
+#' @param options A list of options for [stats::poly()] which should not include
+#'   `x`, `degree`, or `simple`. Note that the option `raw = TRUE` will produce
+#'   the regular polynomial values (not orthogonalized).
 #' @template step-return
 #' @family individual transformation steps
 #' @export
-#' @details `step_poly` can create new features from a single
-#'  variable that enable fitting routines to model this variable in
-#'  a nonlinear manner. The extent of the possible nonlinearity is
-#'  determined by the `degree` argument of
-#'  [stats::poly()]. The original variables are removed
-#'  from the data and new columns are added. The naming convention
-#'  for the new variables is `varname_poly_1` and so on.
+#' @details
 #'
-#'  # Tidying
+#' `step_poly()` can create new features from a single variable that enable
+#' fitting routines to model this variable in a nonlinear manner. The extent of
+#' the possible nonlinearity is determined by the `degree` argument of
+#' [stats::poly()]. The original variables are removed from the data by default,
+#' but can be retained by setting `keep_original_cols = TRUE` and new columns
+#' are added. The naming convention for the new variables is `varname_poly_1`
+#' and so on.
 #'
-#'  When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
-#'  `terms` (the columns that will be affected) and `degree` is returned.
+#' The orthogonal polynomial expansion is used by default because it yields
+#' variables that are uncorrelated and doesn't produce large values which would
+#' otherwise be a problem for large values of `degree`. Orthogonal polynomial
+#' expansion pick up the same signal as their uncorrelated counterpart.
+#'
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms`, `degree` , and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{degree}{integer, the polynomial degree}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' ```{r, echo = FALSE, results="asis"}
 #' step <- "step_poly"
@@ -61,22 +73,17 @@ step_poly <-
            role = "predictor",
            trained = FALSE,
            objects = NULL,
-           degree = 2,
+           degree = 2L,
            options = list(),
            keep_original_cols = FALSE,
            skip = FALSE,
            id = rand_id("poly")) {
-    if (!is_tune(degree)) {
-      degree <- as.integer(degree)
-    }
 
     if (any(names(options) == "degree")) {
       degree <- options$degree
-      message(
-        paste(
-          "The `degree` argument is now a main argument instead of being",
-          "within `options`."
-        )
+      cli::cli_inform(
+        "The {.arg degree} argument is now a main argument instead of being \\
+        within {.arg options}."
       )
     }
 
@@ -132,6 +139,8 @@ poly_wrapper <- function(x, args) {
 prep.step_poly <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names], types = c("double", "integer"))
+  check_number_whole(x$degree, arg = "degree", min = 1)
+  x$degree <- as.integer(x$degree)
 
   opts <- x$options
   opts$degree <- x$degree
@@ -180,7 +189,7 @@ bake.step_poly <- function(object, new_data, ...) {
   new_data
 }
 
-
+#' @export
 print.step_poly <-
   function(x, width = max(20, options()$width - 35), ...) {
     title <- "Orthogonal polynomials on "
