@@ -1,4 +1,4 @@
-#' Create a Profiling Version of a Data Set
+#' Create a profiling version of a data set
 #'
 #' `step_profile()` creates a *specification* of a recipe step that will fix the
 #' levels of all variables but one and will create a sequence of values for the
@@ -36,11 +36,16 @@
 #'  `new_data` argument is ignored; the resulting data set is
 #'  based on the fixed and profiled variable's information.
 #'
-#'  # Tidying
+#' # Tidying
 #'
-#'  When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
-#'  `terms` (which is the columns that will be affected) and `type` (fixed
-#'  or profiled) is returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms`, `type` , and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{type}{character, `"fixed"` or `"profiled"`}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' @template case-weights-not-supported
 #'
@@ -108,22 +113,27 @@ step_profile <- function(recipe,
                          trained = FALSE,
                          skip = FALSE,
                          id = rand_id("profile")) {
-  if (pct < 0 | pct > 1) {
-    rlang::abort("`pct should be on [0, 1]`")
-  }
+
+  check_number_decimal(pct, min = 0, max = 1)
+
   if (length(grid) != 2) {
-    rlang::abort("`grid` should have two named elements. See ?step_profile")
+    cli::cli_abort(c(
+      x = "`grid` should have 2 elements, not {length(grid)}.",
+      i = "See {.help [?step_profile](recipes::step_profile)} for information."
+    ))
   }
-  if (all(sort(names(grid)) == c("len", "ptcl"))) {
-    rlang::abort("`grid` should have two named elements. See ?step_profile")
-  }
-  if (grid$len < 2) {
-    rlang::abort("`grid$len should be at least 2.`")
-  }
-  if (!is.logical(grid$pctl)) {
-    rlang::abort("`grid$pctl should be logical.`")
+  if (!identical(sort(names(grid)), c("len", "pctl"))) {
+    cli::cli_abort(c(
+      x = "`grid` should have two named elements {.field len} and \\
+          {.field pctl}, not {.val {sort(names(grid))}}.",
+      i = "See {.help [?step_profile](recipes::step_profile)} for information."
+    ))
   }
 
+  check_number_whole(grid$len, min = 2)
+  check_bool(grid$pctl)
+
+
   add_step(
     recipe,
     step_profile_new(
@@ -163,15 +173,28 @@ prep.step_profile <- function(x, training, info = NULL, ...) {
   fixed_names <- recipes_eval_select(x$terms, training, info)
   profile_name <- recipes_eval_select(x$profile, training, info)
 
+
   if (length(profile_name) != 1) {
-    rlang::abort("Only one variable should be profiled")
-  }
-  if (any(profile_name == fixed_names)) {
-    rlang::abort(
-      paste0(
-        "The profiled variable cannot be in the list of ",
-        "variables to be fixed."
+    msg <- c(x = "{.arg profile} should select only one column")
+
+    if (length(profile_name) == 0) {
+      msg <- c(msg, i = "No columns were selected.")
+    } else {
+      msg <- c(
+        msg,
+        i = "{length(profile_name)} columns were selected: \\
+        {.var {profile_name}}."
       )
+    }
+
+    cli::cli_abort(msg)
+  }
+
+  if (any(profile_name == fixed_names)) {
+    offenders <- fixed_names[profile_name == fixed_names]
+    cli::cli_abort(
+      "The profiled variable cannot be in the list of variables to be \\
+      fixed. {.var {offenders}} was in both."
     )
   }
   fixed_vals <- lapply(
@@ -221,6 +244,7 @@ bake.step_profile <- function(object, new_data, ...) {
   new_data
 }
 
+#' @export
 print.step_profile <-
   function(x, width = max(20, options()$width - 22), ...) {
     title <- "Profiling data set for "
@@ -269,10 +293,10 @@ fixed <- function(x, pct, index, ...) UseMethod("fixed")
 #' @export
 #' @rdname fixed
 fixed.default <- function(x, pct, index, ...) {
-  rlang::abort("No method for determining a value to fix for ",
-    "objects of class(s) ",
-    paste0("'", class(x), "'", collapse = ","),
-    call. = FALSE
+  classes <- class(x)
+  cli::cli_abort(
+    "No method for determining a value to fix for objects of class{?es}: \\
+    {.cls {classes}}."
   )
 }
 #' @export
