@@ -1,13 +1,11 @@
-#' Scaling Numeric Data to a Specific Range
+#' Scaling numeric data to a specific range
 #'
 #' `step_range()` creates a *specification* of a recipe step that will normalize
 #' numeric data to be within a pre-defined range of values.
 #'
 #' @inheritParams step_center
-#' @param min A single numeric value for the smallest value in the
-#'  range.
-#' @param max A single numeric value for the largest value in the
-#'  range.
+#' @param min,max Single numeric values for the smallest (or largest) value in
+#' the transformed data.
 #' @param clipping A single logical value for determining whether
 #'  application of transformation onto new data should be forced
 #'  to be inside `min` and `max`. Defaults to TRUE.
@@ -22,11 +20,17 @@
 #'  the training set, the new values are truncated at `min` or
 #'  `max`.
 #'
-#'  # Tidying
+#' # Tidying
 #'
-#'  When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
-#'  `terms` (the selectors or variables selected), `min`, and `max` is
-#'  returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms`, `min`, `max` , and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{min}{numeric, lower range}
+#'   \item{max}{numeric, upper range}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' @template case-weights-not-supported
 #'
@@ -100,11 +104,29 @@ step_range_new <-
 prep.step_range <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names], types = c("double", "integer"))
+  check_number_decimal(x$min, arg = "min")
+  check_number_decimal(x$max, arg = "max")
+  check_bool(x$clipping, arg = "clipping")
 
   mins <-
     vapply(training[, col_names], min, c(min = 0), na.rm = TRUE)
   maxs <-
     vapply(training[, col_names], max, c(max = 0), na.rm = TRUE)
+
+  inf_cols <- col_names[is.infinite(mins) | is.infinite(maxs)]
+  if (length(inf_cols) > 0) {
+    cli::cli_warn(
+      "Column{?s} {.var {inf_cols}} returned NaN. \\
+      Consider avoiding `Inf` values before normalising.")
+  }
+  zero_range_cols <- col_names[maxs - mins == 0]
+  if (length(zero_range_cols) > 0) {
+    cli::cli_warn(
+      "Column{?s} {.var {zero_range_cols}} returned NaN. Consider using \\
+       `step_zv()` to remove variables containing only a single value."
+    )
+  }
+
   step_range_new(
     terms = x$terms,
     role = x$role,
@@ -139,6 +161,7 @@ bake.step_range <- function(object, new_data, ...) {
   new_data
 }
 
+#' @export
 print.step_range <-
   function(x, width = max(20, options()$width - 30), ...) {
     title <- glue("Range scaling to [{x$min},{x$max}] for ")
