@@ -13,12 +13,25 @@
 #' @template step-return
 #' @family dummy variable and encoding steps
 #' @export
-#' @details The selected variables are releveled to a level
-#' (given by `ref_level`). Placing the `ref_level` in the first
+#' @details
+#'
+#' The selected variables are releveled to a level
+#' (given by `ref_level`), placing the `ref_level` in the first
 #' position.
 #'
 #' Note that if the original columns are character, they will be
-#'  converted to factors by this step.
+#' converted to factors by this step.
+#'
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms`, `value` , and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{value}{character, the value of `ref_level`}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' @template case-weights-not-supported
 #'
@@ -71,31 +84,23 @@ step_relevel_new <-
 #' @export
 prep.step_relevel <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
-  check_type(training[, col_names], types = c("string", "factor", "ordered"))
+  check_type(training[, col_names], types = c("string", "factor"))
+  check_string(x$ref_level, arg = "ref_level", allow_empty = FALSE)
 
   # Get existing levels and their factor type (i.e. ordered)
   objects <- lapply(training[, col_names], get_existing_values)
   # Check to make sure that no ordered levels are provided
   order_check <- map_lgl(objects, attr, "is_ordered")
-  if (any(order_check)) {
-    rlang::abort(
-      "Columns contain ordered factors (which cannot be releveled) '",
-      x$ref_level, "': ",
-      paste0(names(order_check)[order_check], collapse = ", ")
-    )
-  }
 
   # Check to make sure that the reference level exists in the factor
   ref_check <- map_lgl(objects, function(x, y) !y %in% x,
     y = x$ref_level
   )
   if (any(ref_check)) {
-    rlang::abort(
-      paste0(
-        "Columns must contain the reference level '",
-        x$ref_level, "': ",
-        paste0(names(ref_check)[ref_check], collapse = ", ")
-      )
+    offenders <- names(order_check)[!order_check]
+    cli::cli_abort(
+      "{cli::qty(length(offenders))}The following column{?s} doesn't include \\
+      required reference level {.val {x$ref_level}}: {.var {offenders}}."
     )
   }
 
@@ -125,6 +130,7 @@ bake.step_relevel <- function(object, new_data, ...) {
   new_data
 }
 
+#' @export
 print.step_relevel <-
   function(x, width = max(20, options()$width - 30), ...) {
     title <- "Re-order factor level to ref_level for "
