@@ -1,4 +1,4 @@
-#' Monotone Splines
+#' Monotone splines
 #'
 #' `step_spline_monotone()` creates a *specification* of a recipe step that
 #' creates monotone spline features.
@@ -29,8 +29,13 @@
 #'
 #' # Tidying
 #'
-#'  When you [`tidy()`][tidy.recipe()] this step, a tibble with column
-#'  `terms` (the columns that will be affected) is returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms` and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' ```{r, echo = FALSE, results="asis"}
 #' step <- "step_spline_monotone"
@@ -120,21 +125,23 @@ step_spline_monotone_new <-
 prep.step_spline_monotone <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names], types = c("double", "integer"))
+  check_bool(x$complete_set, arg = "complete_set")
+  check_number_whole(x$degree, arg = "degree", min = 0)
+  check_number_whole(x$deg_free, arg = "deg_free", min = 0)
 
-  res <-
-    purrr::map2(
-      training[, col_names],
-      col_names,
-      ~ spline2_create(
-        .x,
-        nm = .y,
-        .fn = "iSpline",
-        df = x$deg_free,
-        degree = x$degree,
-        complete_set = x$complete_set,
-        fn_opts = x$options
-      )
+  res <- list()
+
+  for (col_name in col_names) {
+    res[[col_name]] <- spline2_create(
+      training[[col_name]],
+      nm = col_name,
+      .fn = "iSpline",
+      df = x$deg_free,
+      complete_set = x$complete_set,
+      degree = x$degree,
+      fn_opts = x$options
     )
+  }
   # check for errors
   bas_res <- purrr::map_lgl(res, is.null)
   res <- res[!bas_res]
@@ -185,6 +192,7 @@ bake.step_spline_monotone <- function(object, new_data, ...) {
 
 # ------------------------------------------------------------------------------
 
+#' @export
 print.step_spline_monotone <-
   function(x, width = max(20, options()$width - 30), ...) {
     title <- "Monotone spline expansion "
