@@ -119,20 +119,23 @@ step_spline_natural_new <-
 prep.step_spline_natural <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names], types = c("double", "integer"))
+  check_bool(x$complete_set, arg = "complete_set")
+  check_number_whole(x$deg_free, arg = "deg_free", min = 2)
 
-  res <-
-    purrr::map2(
-      training[, col_names],
-      col_names,
-      ~ spline2_create(
-        .x,
-        nm = .y,
-        .fn = "naturalSpline",
-        df = max(x$deg_free, 2),
-        complete_set = x$complete_set,
-        fn_opts = x$options
-      )
+  res <- list()
+
+  for (col_name in col_names) {
+    res[[col_name]] <- spline2_create(
+      training[[col_name]],
+      nm = col_name,
+      .fn = "naturalSpline",
+      df = max(x$deg_free, 2),
+      complete_set = x$complete_set,
+      degree = x$degree,
+      fn_opts = x$options
     )
+  }
+
   # check for errors
   bas_res <- purrr::map_lgl(res, is.null)
   res <- res[!bas_res]
@@ -182,6 +185,7 @@ bake.step_spline_natural <- function(object, new_data, ...) {
 
 # ------------------------------------------------------------------------------
 
+#' @export
 print.step_spline_natural <-
   function(x, width = max(20, options()$width - 30), ...) {
     title <- "Natural spline expansion "
