@@ -69,6 +69,30 @@ test_that("correct basis functions", {
   expect_equal(hydrogen_bs_te_res, hydrogen_bs_te_exp)
 })
 
+test_that("options(knots) works correctly (#1297)", {
+  exmaple_data <- tibble(x = seq(-2, 2, 0.01))
+
+  rec_res <- recipe(~., data = exmaple_data) %>% 
+    step_bs(x, options = list(knots = seq(-1, 1, 0.125), 
+                              Boundary.knots = c(-2.5, 2.5))) %>% 
+    prep() %>% 
+    bake(new_data = NULL)
+
+  mm_res <- model.matrix(
+    ~ splines::bs(
+      x, 
+      knots = seq(-1, 1, 0.125), 
+      Boundary.knots = c(-2.5, 2.5)
+    ) - 1, 
+    data = exmaple_data
+  )
+
+  attr(mm_res, "assign") <- NULL
+  mm_res <- setNames(as_tibble(mm_res), names(rec_res))
+
+  expect_identical(rec_res, mm_res)
+})
+
 test_that("check_name() is used", {
   dat <- mtcars
   dat$mpg_bs_1 <- dat$mpg
@@ -119,8 +143,7 @@ test_that("bake method errors when needed non-standard role columns are missing"
 
   with_bs <- prep(with_bs, training = biomass_tr, verbose = FALSE)
 
-  expect_error(bake(with_bs, new_data = biomass_tr[,c(-4)]),
-               class = "new_data_missing_column")
+  expect_snapshot(error = TRUE, bake(with_bs, new_data = biomass_tr[,c(-4)]))
 })
 
 test_that("empty printing", {
@@ -196,9 +219,8 @@ test_that("keep_original_cols - can prep recipes with it missing", {
     rec <- prep(rec)
   )
 
-  expect_error(
-    bake(rec, new_data = mtcars),
-    NA
+  expect_no_error(
+    bake(rec, new_data = mtcars)
   )
 })
 
