@@ -15,7 +15,7 @@ sacr$city[sample(1:nrow(sacr), 20)] <- NA_character_
 sacr_missing <- sacr
 
 sacr$city[is.na(sacr$city)] <- "missing"
-sacr <- sacr[complete.cases(sacr), -3]
+sacr <- sacr[vec_detect_complete(sacr), -3]
 
 sacr_fac <- sacr
 sacr_fac$city <- factor(sacr_fac$city)
@@ -65,23 +65,22 @@ test_that("dummy variables with factor inputs", {
   )
 })
 
-test_that("dummy variables with non-factor inputs", {
+test_that("dummy variables errors with character inputs", {
   rec <- recipe(sqft ~ zip + city, data = sacr)
   dummy <- rec %>% step_dummy(city, zip)
 
-  expect_snapshot(error = TRUE,
-    prep(dummy, training = sacr, verbose = FALSE, strings_as_factors = FALSE)
-  )
-
-  sacr_fac_ish <-
-    sacr_fac %>%
-    mutate(city = as.character(city))
-
   expect_snapshot(
     error = TRUE,
-    recipe(sqft ~ zip + price + city, data = sacr_fac_ish) %>%
+    prep(dummy, training = sacr, verbose = FALSE, strings_as_factors = FALSE)
+  )
+})
+
+test_that("check_type() is used", {
+  expect_snapshot(
+    error = TRUE,
+    recipe(sqft ~ zip + price + city, data = sacr) %>%
       step_dummy(city, zip, price) %>%
-      prep(training = sacr_fac_ish, verbose = FALSE, strings_as_factors = FALSE)
+      prep()
   )
 })
 
@@ -168,10 +167,10 @@ test_that("tests for NA values in factor", {
   )
 
   expect_true(
-    all(complete.cases(factors_data_0) == complete.cases(sacr_missing[, "city"]))
+    all(vec_detect_complete(factors_data_0) == vec_detect_complete(sacr_missing[, "city"]))
   )
   expect_true(
-    all(complete.cases(factors_data_1) == complete.cases(sacr_missing[, "city"]))
+    all(vec_detect_complete(factors_data_1) == vec_detect_complete(sacr_missing[, "city"]))
   )
 })
 
@@ -190,15 +189,13 @@ test_that("tests for NA values in ordered factor", {
   )
 
   expect_true(
-    all(complete.cases(factors_data_0) == complete.cases(sacr_ordered[, "city"]))
+    all(vec_detect_complete(factors_data_0) == vec_detect_complete(sacr_ordered[, "city"]))
   )
   expect_true(
-    all(complete.cases(factors_data_1) == complete.cases(sacr_ordered[, "city"]))
+    all(vec_detect_complete(factors_data_1) == vec_detect_complete(sacr_ordered[, "city"]))
   )
 })
 
-
-
 test_that("new levels", {
   df <- data.frame(
     y = c(1, 0, 1, 1, 0, 0, 0, 1, 1, 1, 0, 0, 1, 0, 1, 0, 0, 0, 1, 0),
@@ -216,10 +213,10 @@ test_that("new levels", {
   testing$x1 <- as.factor(testing$x1)
 
   expect_snapshot(
-    recipes:::warn_new_levels(testing$x1, levels(training$x1))
+    recipes:::warn_new_levels(testing$x1, levels(training$x1), "column", "step_dummy")
   )
   expect_silent(
-    recipes:::warn_new_levels(training$x1, levels(training$x1))
+    recipes:::warn_new_levels(training$x1, levels(training$x1), "column", "step_dummy")
   )
 
   rec <- recipe(y ~ x1, data = training) %>%
@@ -232,6 +229,16 @@ test_that("new levels", {
   )
 })
 
+test_that("warns about NA in column (#450)", {
+  data <- data.frame(a = c(LETTERS, NA))
+
+  expect_snapshot(
+    tmp <- recipe(~ a, data = data) %>%
+      step_dummy(a) %>%
+      prep()
+  )
+})
+
 test_that("tests for issue #301", {
   rec <- recipe(~Species, data = iris)
   dummies <- rec %>% step_dummy(Species)
@@ -316,7 +323,7 @@ test_that("check_name() is used", {
   dat <- iris
   dat$Species_versicolor <- dat$Species
 
-  rec <- recipe(~., data = dat) |>
+  rec <- recipe(~., data = dat) %>%
     step_dummy(Species)
 
   expect_snapshot(
@@ -325,6 +332,97 @@ test_that("check_name() is used", {
   )
 })
 
+test_that("throws a informative error for too many levels (#828)", {
+  skip_on_cran()
+  dat <- data.frame(x = as.character(1:123456))
+
+  rec <- recipe(~ ., data = dat) %>%
+    step_dummy(x)
+
+  expect_snapshot(
+    error = TRUE,
+    prep(rec)
+  )
+})
+
+test_that("throws an informative error for single level", {
+  expect_snapshot(
+    error = TRUE,
+    recipe(~ ., data = data.frame(x = "only-level")) %>%
+      step_dummy(x) %>%
+      prep()
+  )
+})
+
+test_that("sparse = 'yes' works", {
+  rec <- recipe(~ ., data = tibble(x = c(NA, letters)))
+
+  suppressWarnings({
+    dense <- rec %>% step_dummy(x, sparse = "no") %>% prep() %>% bake(NULL)
+    dense <- purrr::map(dense, as.integer) %>% tibble::new_tibble()
+    sparse <- rec %>% step_dummy(x, sparse = "yes") %>% prep() %>% bake(NULL)
+  })
+
+  expect_identical(dense, sparse)
+
+  expect_false(any(vapply(dense, sparsevctrs::is_sparse_vector, logical(1))))
+  expect_true(all(vapply(sparse, sparsevctrs::is_sparse_vector, logical(1))))
+})
+
+test_that("sparse = 'yes' errors on unsupported contrasts", {
+  go_helmert <- getOption("contrasts")
+  go_helmert["unordered"] <- "contr.helmert"
+  withr::local_options(contrasts = go_helmert)
+
+  expect_snapshot(
+    error = TRUE,
+    recipe(~ ., data = tibble(x = letters)) %>% 
+      step_dummy(x, sparse = "yes") %>% 
+      prep()
+  )
+})
+
+test_that("sparse argument is backwards compatible", {
+  dat <- tibble(x = c(letters))
+  rec <- recipe(~ ., data = dat) %>%
+    step_dummy(x) %>%
+    prep()
+
+  exp <- bake(rec, dat)
+
+  # Simulate old recipe
+  rec$steps[[1]]$sparse <- NULL
+
+  expect_identical(
+    bake(rec, dat),
+    exp
+  )
+})
+
+test_that(".recipes_toggle_sparse_args works", {
+  rec <- recipe(~., iris) %>%
+    step_dummy(all_nominal_predictors(), sparse = "auto")
+
+  exp <- rec %>% prep() %>% bake(NULL) %>% sparsevctrs::sparsity()
+
+ expect_equal(
+    .recipes_estimate_sparsity(rec),
+    exp
+  )
+
+  iris$Species <- as.character(iris$Species)
+
+  rec <- recipe(~., iris) %>%
+    step_dummy(all_nominal_predictors(), sparse = "auto")
+
+  exp <- rec %>% prep() %>% bake(NULL) %>% sparsevctrs::sparsity()
+
+ expect_equal(
+    .recipes_estimate_sparsity(rec),
+    exp
+  )
+})
+
 # Infrastructure ---------------------------------------------------------------
 
 test_that("bake method errors when needed non-standard role columns are missing", {
@@ -334,8 +432,10 @@ test_that("bake method errors when needed non-standard role columns are missing"
     update_role_requirements(role = "potato", bake = FALSE)
   dummy_trained <- prep(dummy, training = sacr_fac, verbose = FALSE, strings_as_factors = FALSE)
 
-  expect_error(bake(dummy_trained, new_data = sacr_fac[, 3:4], all_predictors()),
-               class = "new_data_missing_column")
+  expect_snapshot(
+    error = TRUE,
+    bake(dummy_trained, new_data = sacr_fac[, 3:4], all_predictors())
+  )
 })
 
 test_that("empty printing", {
@@ -411,9 +511,8 @@ test_that("keep_original_cols - can prep recipes with it missing", {
     rec <- prep(rec)
   )
 
-  expect_error(
-    bake(rec, new_data = iris),
-    NA
+  expect_no_error(
+    bake(rec, new_data = iris)
   )
 })
 
@@ -424,3 +523,22 @@ test_that("printing", {
   expect_snapshot(print(rec))
   expect_snapshot(prep(rec))
 })
+
+
+test_that("bad args", {
+  skip_if_not_installed("modeldata")
+  data(Sacramento, package = "modeldata")
+
+  expect_snapshot(
+    recipe(~ city + sqft + price, data = Sacramento) %>%
+      step_dummy(city, one_hot = 2) %>%
+      prep(),
+    error = TRUE
+  )
+  expect_snapshot(
+    recipe(~ city + sqft + price, data = Sacramento) %>%
+      step_dummy(city, naming = NULL) %>%
+      prep(),
+    error = TRUE
+  )
+})
