@@ -157,7 +157,7 @@ test_that("check_name() is used", {
   dat <- mtcars
   dat$geo_dist <- dat$mpg
 
-  rec <- recipe(~., data = dat) |>
+  rec <- recipe(~., data = dat) %>%
     step_geodist(vs, am, ref_lat = 0, ref_lon = 0)
 
   expect_snapshot(
@@ -231,8 +231,11 @@ test_that("bake method errors when needed non-standard role columns are missing"
     update_role(x, y, new_role = "potato") %>%
     update_role_requirements(role = "potato", bake = FALSE)
   rec_trained <- prep(rec, rand_data)
-  expect_error(bake(rec_trained, new_data = rand_data[, 2, drop = FALSE]),
-               class = "new_data_missing_column")
+  
+  expect_snapshot(
+    error = TRUE, 
+    bake(rec_trained, new_data = rand_data[, 2, drop = FALSE])
+  )
 })
 
 test_that("empty printing", {
@@ -327,9 +330,8 @@ test_that("keep_original_cols - can prep recipes with it missing", {
     rec <- prep(rec)
   )
 
-  expect_error(
-    bake(rec, new_data = rand_data),
-    NA
+  expect_no_error(
+    bake(rec, new_data = rand_data)
   )
 })
 
