@@ -99,7 +99,7 @@ test_that("check_name() is used", {
   dat <- mtcars
   dat$IC1 <- dat$mpg
 
-  rec <- recipe(~., data = dat) |>
+  rec <- recipe(~., data = dat) %>%
     step_ica(mpg, disp)
 
   expect_snapshot(
@@ -137,6 +137,25 @@ test_that("Do nothing for num_comps = 0 and keep_original_cols = FALSE (#1152)",
   expect_identical(res, tibble::as_tibble(mtcars))
 })
 
+test_that("rethrows error correctly from implementation", {
+  skip_if_not_installed("dimRed")
+  skip_if_not_installed("fastICA")
+  skip_if_not_installed("RSpectra")
+
+  local_mocked_bindings(
+    .package = "fastICA",
+    fastICA = function(...) {
+      cli::cli_abort("mocked error")
+    }
+  )
+  expect_snapshot(
+    error = TRUE,
+    recipe(~ ., data = mtcars) %>%
+      step_ica(all_predictors()) %>%
+      prep()
+  )
+})
+
 # Infrastructure ---------------------------------------------------------------
 
 test_that("bake method errors when needed non-standard role columns are missing", {
@@ -154,8 +173,10 @@ test_that("bake method errors when needed non-standard role columns are missing"
 
   ica_extract_trained <- prep(ica_extract, training = biomass_tr, verbose = FALSE)
 
-  expect_error(bake(ica_extract_trained, new_data = biomass_tr[, c(-3)]),
-               class = "new_data_missing_column")
+  expect_snapshot(
+    error = TRUE,
+    bake(ica_extract_trained, new_data = biomass_tr[, c(-3)])
+  )
 })
 
 test_that("empty printing", {
@@ -256,9 +277,8 @@ test_that("keep_original_cols - can prep recipes with it missing", {
     rec <- prep(rec)
   )
 
-  expect_error(
-    bake(rec, new_data = mtcars),
-    NA
+  expect_no_error(
+    bake(rec, new_data = mtcars)
   )
 })
 
@@ -292,3 +312,15 @@ test_that("tunable is setup to work with extract_parameter_set_dials", {
   expect_s3_class(params, "parameters")
   expect_identical(nrow(params), 1L)
 })
+
+
+test_that("bad args", {
+  skip_if_not_installed("fastICA")
+
+  expect_snapshot(
+    rec %>%
+      step_ica(carbon, hydrogen, prefix = 2) %>%
+      prep(),
+    error = TRUE
+  )
+})
