@@ -79,13 +79,6 @@ test_that("all NA values", {
   expect_equal(unique(imputed_te$Age), imputed$steps[[1]]$medians$Age)
 })
 
-test_that("Deprecation warning", {
-  expect_snapshot(error = TRUE,
-    recipe(~ ., data = mtcars) %>%
-      step_medianimpute()
-  )
-})
-
 test_that("case weights", {
   credit_tr_cw <- credit_tr %>%
     mutate(Amount = frequency_weights(Amount))
@@ -137,8 +130,7 @@ test_that("bake method errors when needed non-standard role columns are missing"
     update_role_requirements(role = "potato", bake = FALSE)
   imputed <- prep(impute_rec, training = credit_tr, verbose = FALSE)
 
-  expect_error(bake(imputed, new_data = credit_te[, c(-5)]),
-               class = "new_data_missing_column")
+  expect_snapshot(error = TRUE, bake(imputed, new_data = credit_te[, c(-5)]))
 })
 
 test_that("empty printing", {
