@@ -92,13 +92,6 @@ test_that("bad args", {
   )
 })
 
-test_that("Deprecation warning", {
-  expect_snapshot(error = TRUE,
-    recipe(~ ., data = mtcars) %>%
-      step_rollimpute()
-  )
-})
-
 test_that("tunable", {
   rec <-
     recipe(~., data = iris) %>%
@@ -124,8 +117,10 @@ test_that("bake method errors when needed non-standard role columns are missing"
     update_role_requirements(role = "potato", bake = FALSE) %>%
     prep(training = example_data)
 
-  expect_error(bake(seven_pt, new_data = example_data[, c(-2)]),
-               class = "new_data_missing_column")
+  expect_snapshot(
+    error = TRUE,
+    bake(seven_pt, new_data = example_data[, c(-2)])
+  )
 })
 
 test_that("empty printing", {
@@ -187,3 +182,34 @@ test_that("tunable is setup to work with extract_parameter_set_dials", {
   expect_s3_class(params, "parameters")
   expect_identical(nrow(params), 2L)
 })
+
+
+test_that("bad args", {
+  expect_snapshot(
+    recipe(~., data = mtcars) %>%
+      step_impute_roll(
+        all_predictors(),
+        statistic = mean, window = 1
+      ) %>%
+      prep(),
+    error = TRUE
+  )
+  expect_snapshot(
+    recipe(~., data = mtcars) %>%
+      step_impute_roll(
+        all_predictors(),
+        statistic = mean, window = 4
+      ) %>%
+      prep(),
+    error = TRUE
+  )
+  expect_snapshot(
+    recipe(~., data = mtcars) %>%
+      step_impute_roll(
+        all_predictors(),
+        statistic = NULL
+      ) %>%
+      prep(),
+    error = TRUE
+  )
+})
