@@ -43,7 +43,7 @@ test_that("step_indicate_na populates binaries correctly", {
 
 test_that("step_indicate_na on all columns", {
   baked <- recipe(Ozone ~ ., data = airquality) %>%
-    step_indicate_na(everything()) %>%
+    step_indicate_na(all_predictors()) %>%
     prep(airquality, verbose = FALSE, retain = TRUE) %>%
     bake(new_data = NULL)
 
@@ -52,7 +52,7 @@ test_that("step_indicate_na on all columns", {
     c(
       "Solar.R", "Wind", "Temp", "Month", "Day", "Ozone",
       "na_ind_Solar.R", "na_ind_Wind", "na_ind_Temp",
-      "na_ind_Month", "na_ind_Day", "na_ind_Ozone"
+      "na_ind_Month", "na_ind_Day"
     )
   )
 })
@@ -107,8 +107,7 @@ test_that("bake method errors when needed non-standard role columns are missing"
     update_role_requirements(role = "potato", bake = FALSE)%>%
     prep(train, verbose = FALSE, retain = TRUE)
 
-  expect_error(bake(rec1, new_data = test[, 2:3]),
-               class = "new_data_missing_column")
+  expect_snapshot(error = TRUE, bake(rec1, new_data = test[, 2:3]))
 })
 
 test_that("empty printing", {
@@ -184,9 +183,8 @@ test_that("keep_original_cols - can prep recipes with it missing", {
     rec <- prep(rec)
   )
 
-  expect_error(
-    bake(rec, new_data = mtcars),
-    NA
+  expect_no_error(
+    bake(rec, new_data = mtcars)
   )
 })
 
