@@ -233,55 +233,28 @@ test_that("replacing selectors in formulas", {
   )
 })
 
-test_that("missing columns", {
-  skip("redundant with check_new_data checks")
+test_that('with factors', {
+  int_rec <- recipe(Sepal.Width ~ ., data = iris) %>%
+    step_interact(~ (. - Sepal.Width)^2, sep = ":")
 
-  no_fail <-
-    rec %>%
-    step_rm(x1) %>%
-    step_interact(~ x1:x2)
-  expect_snapshot(no_fail_rec <- prep(no_fail, dat_tr))
-  no_fail_res <- bake(no_fail_rec, new_data = NULL) %>% names()
-  expect_true(!any(grepl("_x_", no_fail_res)))
+  suppressWarnings(
+    int_rec_trained <- prep(int_rec, iris)
+  )
 
-  one_int <-
-    rec %>%
-    step_rm(x1) %>%
-    step_interact(~ x1:x2) %>%
-    step_interact(~ x3:x2)
-  expect_snapshot(one_int_rec <- prep(one_int, dat_tr))
-  one_int_res <- bake(one_int_rec, new_data = NULL) %>% names()
-  expect_true(sum(grepl("_x_", one_int_res)) == 1)
+  te_new <- bake(int_rec_trained, new_data = iris, all_predictors(), - Species)
+  te_new <- te_new[, sort(names(te_new))]
+  te_new <- as.matrix(te_new)
 
-  with_selectors <-
-    rec %>%
-    step_rm(x1) %>%
-    step_interact(~ starts_with("x"):starts_with("x")) %>%
-    step_interact(~ x3:x2)
-  expect_warning(prep(with_selectors, dat_tr), regexp = NA)
+  og_terms <- terms(Sepal.Width ~ (.)^2-Species, data = iris)
+  te_og <- model.matrix(og_terms, data = iris)[, -1]
+  te_og <- te_og[, sort(colnames(te_og))]
+
+  rownames(te_new) <- NULL
+  rownames(te_og) <- NULL
+
+  expect_identical(te_og, te_new)
 })
 
-
-# currently failing; try to figure out why
-# test_that('with factors', {
-#   int_rec <- recipe(Sepal.Width ~ ., data = iris) %>%
-#     step_interact(~ (. - Sepal.Width)^3, sep = ":")
-#   int_rec_trained <- prep(int_rec, iris)
-#
-#   te_new <- bake(int_rec_trained, new_data = iris, role = "predictor")
-#   te_new <- te_new[, sort(names(te_new))]
-#   te_new <- as.matrix(te_new)
-#
-#   og_terms <- terms(Sepal.Width ~ (.)^3, data = iris)
-#   te_og <- model.matrix(og_terms, data = iris)[, -1]
-#   te_og <- te_og[, sort(colnames(te_og))]
-#
-#   rownames(te_new) <- NULL
-#   rownames(te_og) <- NULL
-#
-#   all.equal(te_og, te_new)
-# })
-
 test_that("works when formula is passed in as an object", {
   rec1 <- recipe(~., data = mtcars) %>%
     step_interact(terms = ~vs:am, id = "") %>%
@@ -292,6 +265,8 @@ test_that("works when formula is passed in as an object", {
     step_interact(terms = cars_formula, id = "") %>%
     prep()
 
+  rec1$fit_times$elapsed <- 0
+  rec2$fit_times$elapsed <- 0
   expect_identical(rec1, rec2)
 
   cars_formula <- ~ vs:am
@@ -299,9 +274,61 @@ test_that("works when formula is passed in as an object", {
     step_interact(terms = !!cars_formula, id = "") %>%
     prep()
 
+  rec3$fit_times$elapsed <- 0
   expect_identical(rec1, rec3)
 })
 
+test_that("works with long formulas (#1231)", {
+  df_long <- data.frame(
+    a = 1:10,
+    bbbbbbbbbbbbbbbbbbb = 1:10,
+    ccccccccccccccccccc = 1:10,
+    d = 1:10
+  )
+
+  df_short <- data.frame(
+    a = 1:10,
+    b = 1:10,
+    c = 1:10,
+    d = 1:10
+  )
+
+  res_long <- recipe(df_long) %>%
+    step_interact(~starts_with('bbbbbbbbbbbbbb'):starts_with('cccccccccccccc') +
+                     starts_with('bbbbbbbbbbbbbb'):starts_with('d')) %>%
+    prep() %>%
+    bake(new_data = NULL) %>%
+    unname()
+
+  res_short <- recipe(df_short) %>%
+    step_interact(~starts_with('b'):starts_with('c') +
+                     starts_with('b'):starts_with('d')) %>%
+    prep() %>%
+    bake(new_data = NULL) %>%
+    unname()
+
+  expect_identical(res_long, res_short)
+})
+
+test_that("gives informative error if terms isn't a formula (#1299)", {
+  expect_snapshot(
+    error = TRUE,
+    recipe(mpg ~ ., data = mtcars) %>%
+      step_interact(terms = starts_with("dis")) %>%
+      prep()
+  )
+})
+
+test_that("gives informative error if terms isn't a formula (#1299)", {
+  mtcars$am <- as.character(mtcars$am)
+
+  expect_snapshot(
+    tmp <- recipe(mpg ~ ., data = mtcars) %>%
+      step_interact(~disp:am) %>%
+      prep(strings_as_factors = FALSE)
+  )
+})
+
 # Infrastructure ---------------------------------------------------------------
 
 test_that("bake method errors when needed non-standard role columns are missing", {
@@ -315,10 +342,10 @@ test_that("bake method errors when needed non-standard role columns are missing"
       prep(int_rec, training = dat_tr, verbose = FALSE)
   )
 
-  expect_error(bake(int_rec_trained, dat_tr[, 4:6]),
-               class = "new_data_missing_column")
-
-  expect_snapshot(bake(int_rec_trained, dat_tr[, 4:6]), error = TRUE)
+  expect_snapshot(
+    error = TRUE,
+    bake(int_rec_trained, dat_tr[, 4:6])
+  )
 })
 
 test_that("empty printing", {
@@ -394,9 +421,8 @@ test_that("keep_original_cols - can prep recipes with it missing", {
     rec <- prep(rec)
   )
 
-  expect_error(
-    bake(rec, new_data = dat_tr),
-    NA
+  expect_no_error(
+    bake(rec, new_data = dat_tr)
   )
 })
 
@@ -407,3 +433,12 @@ test_that("printing", {
   expect_snapshot(print(rec))
   expect_snapshot(prep(rec))
 })
+
+test_that("bad args", {
+  expect_snapshot(
+    recipe(mpg ~ ., data = mtcars) %>%
+      step_interact(~ disp::wt, sep = TRUE) %>%
+      prep(),
+    error = TRUE
+  )
+})
