@@ -65,9 +65,18 @@ test_that("na_rm argument works for step_normalize", {
   mtcars_na <- mtcars
   mtcars_na[1, 1:4] <- NA
 
-  rec_no_na_rm <- recipe(~., data = mtcars_na) %>%
-    step_normalize(all_predictors(), na_rm = FALSE) %>%
-    prep()
+  expect_snapshot(
+    rec_no_na_rm <- recipe(~., data = mtcars_na) %>%
+      step_normalize(all_predictors(), na_rm = FALSE) %>%
+      prep()
+  )
+
+  expect_snapshot(
+    recipe(~., data = mtcars_na) %>%
+      step_normalize(all_predictors(), na_rm = 2) %>%
+      prep(),
+    error = TRUE
+  )
 
   rec_na_rm <- recipe(~., data = mtcars_na) %>%
     step_normalize(all_predictors(), na_rm = TRUE) %>%
@@ -140,6 +149,16 @@ test_that("normalizing with case weights", {
   expect_snapshot(rec)
 })
 
+test_that("warns when NaN is returned due to Inf or -Inf",{
+  rec <- recipe(~., data = data.frame(x = c(2, 3, 4, Inf))) %>%
+    step_normalize(x)
+  expect_snapshot(prep(rec))
+
+  rec <- recipe(~., data = data.frame(x = c(2, 3, 4, -Inf))) %>%
+    step_normalize(x)
+  expect_snapshot(prep(rec))
+})
+
 # Infrastructure ---------------------------------------------------------------
 
 test_that("bake method errors when needed non-standard role columns are missing", {
@@ -150,8 +169,7 @@ test_that("bake method errors when needed non-standard role columns are missing"
 
   std_trained <- prep(std, training = biomass)
 
-  expect_error(bake(std_trained, new_data = biomass[, 1:2]),
-               class = "new_data_missing_column")
+  expect_snapshot(error = TRUE, bake(std_trained, new_data = biomass[, 1:2]))
 })
 
 test_that("empty printing", {
