@@ -71,6 +71,30 @@ test_that("correct basis functions", {
   expect_equal(hydrogen_ns_te_res, hydrogen_ns_te_exp)
 })
 
+test_that("options(knots) works correctly (#1297)", {
+  exmaple_data <- tibble(x = seq(-2, 2, 0.01))
+
+  rec_res <- recipe(~., data = exmaple_data) %>% 
+    step_ns(x, options = list(knots = seq(-1, 1, 0.125), 
+                              Boundary.knots = c(-1.5, 1.5))) %>% 
+    prep() %>% 
+    bake(new_data = NULL)
+
+  mm_res <- model.matrix(
+    ~ splines::ns(
+      x, 
+      knots = seq(-1, 1, 0.125), 
+      Boundary.knots = c(-1.5, 1.5)
+    ) - 1, 
+    data = exmaple_data
+  )
+
+  attr(mm_res, "assign") <- NULL
+  mm_res <- setNames(as_tibble(mm_res), names(rec_res))
+
+  expect_identical(rec_res, mm_res)
+})
+
 test_that("check_name() is used", {
   dat <- mtcars
   dat$mpg_ns_1 <- dat$mpg
@@ -99,6 +123,18 @@ test_that("tunable", {
   )
 })
 
+test_that("works when baked with 1 row", {
+  rec <- recipe(mpg ~ ., data = mtcars) %>%
+    step_ns(disp) %>%
+    prep()
+
+  expect_no_error(
+    res <- bake(rec, mtcars[1, ])
+  )
+
+  expect_identical(nrow(res), 1L)
+})
+
 # Infrastructure ---------------------------------------------------------------
 
 test_that("bake method errors when needed non-standard role columns are missing", {
@@ -109,8 +145,7 @@ test_that("bake method errors when needed non-standard role columns are missing"
 
   with_ns <- prep(with_ns, training = biomass_tr, verbose = FALSE)
 
-  expect_error(bake(with_ns, new_data = biomass_tr[, c(-3)]),
-               class = "new_data_missing_column")
+  expect_snapshot(error = TRUE, bake(with_ns, new_data = biomass_tr[, c(-3)]))
 })
 
 test_that("empty printing", {
@@ -186,9 +221,8 @@ test_that("keep_original_cols - can prep recipes with it missing", {
     rec <- prep(rec)
   )
 
-  expect_error(
-    bake(rec, new_data = mtcars),
-    NA
+  expect_no_error(
+    bake(rec, new_data = mtcars)
   )
 })
 
