@@ -90,13 +90,12 @@ test_that("tunable", {
 })
 
 test_that("old option argument", {
-  expect_message(
+  expect_snapshot(
     res <-
       recipe(~., data = iris) %>%
       step_poly(Sepal.Width, options = list(degree = 3)) %>%
       prep() %>%
-      bake(new_data = NULL),
-    "The `degree` argument is now a main argument"
+      bake(new_data = NULL)
   )
   exp_names <- c(
     "Sepal.Length", "Petal.Length", "Petal.Width", "Species",
@@ -124,8 +123,7 @@ test_that("bake method errors when needed non-standard role columns are missing"
 
   with_poly <- prep(with_poly, training = biomass_tr, verbose = FALSE)
 
-  expect_error(bake(with_poly, new_data = biomass_tr[, c(-3)]),
-               class = "new_data_missing_column")
+  expect_snapshot(error = TRUE, bake(with_poly, new_data = biomass_tr[, c(-3)]))
 })
 
 test_that("empty printing", {
@@ -201,9 +199,8 @@ test_that("keep_original_cols - can prep recipes with it missing", {
     rec <- prep(rec)
   )
 
-  expect_error(
-    bake(rec, new_data = mtcars),
-    NA
+  expect_no_error(
+    bake(rec, new_data = mtcars)
   )
 })
 
@@ -229,3 +226,14 @@ test_that("tunable is setup to work with extract_parameter_set_dials", {
   expect_s3_class(params, "parameters")
   expect_identical(nrow(params), 1L)
 })
+
+test_that("bad args", {
+
+  expect_snapshot(
+    recipe(mpg ~ ., data = mtcars) %>%
+      step_poly(disp, degree = 0) %>%
+      prep(),
+    error = TRUE
+  )
+
+})
