@@ -88,9 +88,11 @@ test_that("na_rm argument works for step_scale", {
   mtcars_na <- mtcars
   mtcars_na[1, 1:4] <- NA
 
+  expect_snapshot({
   rec_no_na_rm <- recipe(~., data = mtcars_na) %>%
     step_scale(all_predictors(), na_rm = FALSE) %>%
     prep()
+  })
 
   rec_na_rm <- recipe(~., data = mtcars_na) %>%
     step_scale(all_predictors(), na_rm = TRUE) %>%
@@ -108,6 +110,11 @@ test_that("na_rm argument works for step_scale", {
     tidy(rec_na_rm, 1)$value,
     unname(exp_na_rm)
   )
+  expect_snapshot(
+    rec_no_na_rm <- recipe(~., data = mtcars_na) %>%
+      step_scale(all_predictors(), na_rm = "FALSE") %>%
+      prep(),
+    error = TRUE)
 })
 
 test_that("warns on zv",{
@@ -115,6 +122,13 @@ test_that("warns on zv",{
   expect_snapshot(prep(rec1))
 })
 
+test_that("warns when NaN is returned",{
+  rec1 <- rec %>%
+    step_log(sulfur) %>%
+    step_scale(sulfur)
+  expect_snapshot(prep(rec1))
+})
+
 test_that("scaling with case weights", {
   mtcars_freq <- mtcars
   mtcars_freq$cyl <- frequency_weights(mtcars_freq$cyl)
@@ -157,8 +171,7 @@ test_that("bake method errors when needed non-standard role columns are missing"
 
   std_trained <- prep(std, training = biomass)
 
-  expect_error(bake(std_trained, new_data = biomass[, 1:2]),
-               class = "new_data_missing_column")
+  expect_snapshot(error = TRUE, bake(std_trained, new_data = biomass[, 1:2]))
 })
 
 test_that("empty printing", {
