@@ -107,13 +107,6 @@ test_that("quasiquotation", {
   expect_equal(dplyr_train, rec_2_train)
 })
 
-test_that("printing", {
-  rec <- recipe(~., data = iris) %>%
-    step_select(Species, starts_with("Sepal"), petal_width = Petal.Width)
-  expect_snapshot(print(rec))
-  expect_snapshot(prep(rec))
-})
-
 test_that("tidying", {
   iris_tbl <- as_tibble(iris)
   iris_train <- slice(iris_tbl, 1:75)
@@ -139,6 +132,8 @@ test_that("tidying", {
   })
 })
 
+# Infrastructure ---------------------------------------------------------------
+
 test_that("bake method errors when needed non-standard role columns are missing", {
   rec <- recipe(~., data = mtcars) %>%
     step_select(cyl) %>%
@@ -146,6 +141,43 @@ test_that("bake method errors when needed non-standard role columns are missing"
     update_role_requirements(role = "potato", bake = FALSE) %>%
     prep(training = mtcars)
 
-  expect_error(bake(rec, new_data = mtcars[, c(-2)]),
-               class = "new_data_missing_column")
+  expect_snapshot(error = TRUE, bake(rec, new_data = mtcars[, c(-2)]))
+})
+
+test_that("empty printing", {
+  rec <- recipe(mpg ~ ., mtcars)
+  rec <- step_select(rec)
+
+  expect_snapshot(rec)
+
+  rec <- prep(rec, mtcars)
+
+  expect_snapshot(rec)
+})
+
+test_that("empty selection prep/bake is a no-op", {
+  # Here for completeness
+  # step_select() will mimick dplyr::select() by not selecting anything
+  expect_true(TRUE)
+})
+
+test_that("empty selection tidy method works", {
+  rec <- recipe(mpg ~ ., mtcars)
+  rec <- step_select(rec)
+
+  expect <- tibble(terms = character(), id = character())
+
+  expect_identical(tidy(rec, number = 1), expect)
+
+  rec <- prep(rec, mtcars)
+
+  expect_identical(tidy(rec, number = 1), expect)
+})
+
+test_that("printing", {
+  rec <- recipe(~., data = iris) %>%
+    step_select(Species)
+
+  expect_snapshot(print(rec))
+  expect_snapshot(prep(rec))
 })
