@@ -73,6 +73,36 @@ test_that("correct basis functions", {
   expect_equal(hydrogen_ns_te_res, hydrogen_ns_te_exp)
 })
 
+test_that("errors if degree > deg_free (#1170)", {
+  skip_if_not_installed("splines2")
+
+  expect_no_error(
+    recipe(~., data = mtcars) %>%
+      step_spline_b(mpg, degree = 2, deg_free = 3, complete_set = TRUE) %>%
+      prep()
+  )
+
+  expect_no_error(
+    recipe(~., data = mtcars) %>%
+      step_spline_b(mpg, degree = 3, deg_free = 3, complete_set = FALSE) %>%
+      prep()
+  )
+
+  expect_snapshot(
+    error = TRUE,
+    recipe(~., data = mtcars) %>%
+      step_spline_b(mpg, degree = 3, deg_free = 3, complete_set = TRUE) %>%
+      prep()
+  )
+
+  expect_snapshot(
+    error = TRUE,
+    recipe(~., data = mtcars) %>%
+      step_spline_b(mpg, degree = 4, deg_free = 3, complete_set = FALSE) %>%
+      prep()
+  )
+})
+
 test_that("check_name() is used", {
   dat <- mtcars
   dat$mpg_01 <- dat$mpg
@@ -131,8 +161,7 @@ test_that("bake method errors when needed non-standard role columns are missing"
 
   rec_trained <- prep(rec, training = mtcars)
 
-  expect_error(bake(rec_trained, new_data = mtcars[, -3]),
-               class = "new_data_missing_column")
+  expect_snapshot(error = TRUE, bake(rec_trained, new_data = mtcars[, -3]))
 })
 
 test_that("empty printing", {
@@ -226,3 +255,26 @@ test_that("tunable is setup to work with extract_parameter_set_dials", {
   expect_s3_class(params, "parameters")
   expect_identical(nrow(params), 2L)
 })
+
+test_that("bad args", {
+  skip_if_not_installed("splines2")
+
+  expect_snapshot(
+    recipe(mpg ~ ., data = mtcars) %>%
+      step_spline_b(disp, degree = -1) %>%
+      prep(),
+    error = TRUE
+  )
+  expect_snapshot(
+    recipe(mpg ~ ., data = mtcars) %>%
+      step_spline_b(disp, deg_free = "a") %>%
+      prep(),
+    error = TRUE
+  )
+  expect_snapshot(
+    recipe(mpg ~ ., data = mtcars) %>%
+      step_spline_b(disp, complete_set = 1) %>%
+      prep(),
+    error = TRUE
+  )
+})
